# -*- coding: utf-8 -*-

"""

qrstu.guess_data

Data for guessing encoding accidents


Copyright (C) 2023 Rainer Schwarzbach

This file is part of qrstu.

qrstu is free software: you can redistribute it and/or modify
it under the terms of the MIT License.

qrstu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the LICENSE file for more details.

"""


from typing import Dict, List


SUSPICIOUS_FRAGMENTS: Dict[str, List[str]] = {
    "cp037": [
        "Cq",
        "B¿",
        "B]",
        "C^",
        "C¨",
        "C´",
        "B£",
        "B^",
        "B¡",
        "B[",
        "Cw",
        "B½",
        "Cf",
        "Bu",
        "B§",
        "B~",
        "B×",
        "C°",
        "C¸",
        "CÆ",
        "BÞ",
        "Bt",
        "Bv",
        "B¼",
        "Bz",
        "Bx",
        "B¶",
        "B¯",
        "B¨",
        "B´",
        "B®",
        "By",
        "B©",
        "Cp",
        "BÝ",
        "C©",
        "C¶",
        "C¥",
        "C·",
        "C§",
        "B¾",
        "C]",
        "C¯",
        "C¾",
        "C[",
        "C×",
        "C¼",
        "B¥",
        "Cm",
        "Co",
        "Ck",
        "Cl",
        "Cn",
        "B·",
        "Cº",
        "Cæ",
        "Cr",
        "Cª",
        "B¤",
    ],
    "cp273": [
        "Cq",
        "B¿",
        "B|",
        "C¢",
        "C¨",
        "C´",
        "B£",
        "B¢",
        "B¡",
        "B¬",
        "Cw",
        "B½",
        "Cf",
        "Bu",
        "B@",
        "C¤",
        "Bß",
        "B×",
        "C°",
        "C¸",
        "CÆ",
        "BÞ",
        "Bs",
        "Bt",
        "Bv",
        "B¼",
        "Bz",
        "B¶",
        "B‾",
        "B¨",
        "B´",
        "BÐ",
        "SØ´",
        "By",
        "B©",
        "Cp",
        "Cu",
        "BÝ",
        "C©",
        "Bw",
        "C¥",
        "C·",
        "C@",
        "C‾",
        "B¾",
        "C|",
        "C¾",
        "C¬",
        "C×",
        "Co",
        "C¼",
        "B¥",
        "Cm",
        "Ck",
        "Cl",
        "Cn",
        "B·",
        "Cº",
        "Cr",
        "Cª",
        "B¤",
    ],
    "cp424": [
        "B]",
        "B£",
        "B^",
        "B½",
        "Bu",
        "B§",
        "Bt",
        "Bv",
        "B¼",
        "Bz",
        "Bx",
        "B¶",
        "B¯",
        "B¨",
        "B´",
        "B®",
        "By",
        "B©",
        "Cp",
        "B¾",
        "C¼",
        "B¥",
        "B·",
        "B¤",
    ],
    "cp437": [
        "├ç",
        "├╝",
        "├⌐",
        "├ó",
        "├ñ",
        "├á",
        "├Ñ",
        "├º",
        "├¬",
        "├½",
        "├¿",
        "├»",
        "├«",
        "├¼",
        "├ä",
        "├à",
        "├ë",
        "├ª",
        "├å",
        "├┤",
        "├╢",
        "├▓",
        "├╗",
        "├╣",
        "├┐",
        "├û",
        "├£",
        "┬ó",
        "┬ú",
        "┬Ñ",
        "Γéº",
        "╞Æ",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├æ",
        "┬¬",
        "┬║",
        "┬┐",
        "ΓîÉ",
        "┬¼",
        "┬╜",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "Γûæ",
        "ΓûÆ",
        "Γûô",
        "Γöé",
        "Γöñ",
        "Γòí",
        "Γòó",
        "Γòû",
        "Γòò",
        "Γòú",
        "Γòæ",
        "Γòù",
        "Γò¥",
        "Γò£",
        "Γò¢",
        "ΓöÉ",
        "Γöö",
        "Γö┤",
        "Γö¼",
        "Γö£",
        "ΓöÇ",
        "Γö╝",
        "Γò₧",
        "Γòƒ",
        "ΓòÜ",
        "Γòö",
        "Γò⌐",
        "Γòª",
        "Γòá",
        "ΓòÉ",
        "Γò¼",
        "Γòº",
        "Γò¿",
        "Γòñ",
        "ΓòÑ",
        "ΓòÖ",
        "Γòÿ",
        "ΓòÆ",
        "Γòô",
        "Γò½",
        "Γò¬",
        "Γöÿ",
        "Γöî",
        "Γûê",
        "Γûä",
        "Γûî",
        "ΓûÉ",
        "ΓûÇ",
        "╬▒",
        "├ƒ",
        "╬ô",
        "╧Ç",
        "╬ú",
        "╧â",
        "┬╡",
        "╧ä",
        "╬ª",
        "╬ÿ",
        "╬⌐",
        "╬┤",
        "Γê₧",
        "╧å",
        "╬╡",
        "Γê⌐",
        "Γëí",
        "┬▒",
        "ΓëÑ",
        "Γëñ",
        "Γîá",
        "Γîí",
        "├╖",
        "Γëê",
        "┬░",
        "ΓêÖ",
        "┬╖",
        "ΓêÜ",
        "Γü┐",
        "┬▓",
        "Γûá",
        "┬á",
    ],
    "cp500": [
        "Cq",
        "B¿",
        "B|",
        "C¢",
        "C¨",
        "C´",
        "B£",
        "B¢",
        "B¡",
        "B¬",
        "Cw",
        "B½",
        "Cf",
        "Bu",
        "B§",
        "B~",
        "B×",
        "C°",
        "C¸",
        "CÆ",
        "BÞ",
        "Bs",
        "Bt",
        "Bv",
        "B¼",
        "Bz",
        "Bx",
        "B¶",
        "B¯",
        "B¨",
        "B´",
        "BÐ",
        "B®",
        "By",
        "B©",
        "Cp",
        "BÝ",
        "C©",
        "C¶",
        "C¥",
        "C·",
        "C§",
        "B¾",
        "C|",
        "C¯",
        "C¾",
        "C¬",
        "C×",
        "C¼",
        "B¥",
        "Cm",
        "Co",
        "Ck",
        "Cl",
        "Cn",
        "B·",
        "Cº",
        "Cæ",
        "Cr",
        "Cª",
        "B¤",
    ],
    "cp720": [
        "┬\x80",
        "┬\x81",
        "├ر",
        "├ت",
        "┬\x84",
        "├ب",
        "┬\x86",
        "├د",
        "├ز",
        "├س",
        "├ذ",
        "├»",
        "├«",
        "┬\x8d",
        "┬\x8e",
        "┬\x8f",
        "┬\x90",
        "┘ّ",
        "┘ْ",
        "├┤",
        "┬ج",
        "┘\x80",
        "├╗",
        "├╣",
        "╪ة",
        "╪ت",
        "╪ث",
        "╪ج",
        "┬ث",
        "╪ح",
        "╪خ",
        "╪د",
        "╪ذ",
        "╪ر",
        "╪ز",
        "╪س",
        "╪ش",
        "╪ص",
        "╪«",
        "╪»",
        "╪░",
        "╪▒",
        "╪▓",
        "╪│",
        "╪┤",
        "╪╡",
        "┬س",
        "┬╗",
        "ظûّ",
        "ظûْ",
        "ظûô",
        "ظ¤é",
        "ظ¤ج",
        "ظـة",
        "ظـت",
        "ظـû",
        "ظــ",
        "ظـث",
        "ظـّ",
        "ظـù",
        "ظـإ",
        "ظـ£",
        "ظـؤ",
        "ظ¤\x90",
        "ظ¤¤",
        "ظ¤┤",
        "ظ¤ش",
        "ظ¤£",
        "ظ¤\x80",
        "ظ¤╝",
        "ظـئ",
        "ظـا",
        "ظـأ",
        "ظـ¤",
        "ظـر",
        "ظـخ",
        "ظـب",
        "ظـ\x90",
        "ظـش",
        "ظـد",
        "ظـذ",
        "ظـج",
        "ظـح",
        "ظـآ",
        "ظـء",
        "ظـْ",
        "ظـô",
        "ظـس",
        "ظـز",
        "ظ¤ء",
        "ظ¤î",
        "ظûê",
        "ظû\x84",
        "ظûî",
        "ظû\x90",
        "ظû\x80",
        "╪╢",
        "╪╖",
        "╪╕",
        "╪╣",
        "╪║",
        "┘\x81",
        "┬╡",
        "┘é",
        "┘â",
        "┘\x84",
        "┘à",
        "┘\x86",
        "┘ç",
        "┘ê",
        "┘ë",
        "┘è",
        "ظëة",
        "┘ï",
        "┘î",
        "┘\x8d",
        "┘\x8e",
        "┘\x8f",
        "┘\x90",
        "ظëê",
        "┬░",
        "ظêآ",
        "┬╖",
        "ظêأ",
        "ظ\x81┐",
        "┬▓",
        "ظûب",
        "┬ب",
    ],
    "cp737": [
        "╬Σ",
        "╬Τ",
        "╬Υ",
        "╬Φ",
        "╬Χ",
        "╬Ψ",
        "╬Ω",
        "╬α",
        "╬β",
        "╬γ",
        "╬δ",
        "╬ε",
        "╬ζ",
        "╬η",
        "╬θ",
        "╬ι",
        "╬κ",
        "╬μ",
        "╬ν",
        "╬ξ",
        "╬ο",
        "╬π",
        "╬ρ",
        "╬σ",
        "╬▒",
        "╬▓",
        "╬│",
        "╬┤",
        "╬╡",
        "╬╢",
        "╬╖",
        "╬╕",
        "╬╣",
        "╬║",
        "╬╗",
        "╬╝",
        "╬╜",
        "╬╛",
        "╬┐",
        "╧Α",
        "╧Β",
        "╧Δ",
        "╧Γ",
        "╧Ε",
        "╧Ζ",
        "╧Η",
        "╧Θ",
        "╧Ι",
        "έΨΣ",
        "έΨΤ",
        "έΨΥ",
        "έΦΓ",
        "έΦν",
        "έΧκ",
        "έΧλ",
        "έΧΨ",
        "έΧΧ",
        "έΧμ",
        "έΧΣ",
        "έΧΩ",
        "έΧζ",
        "έΧε",
        "έΧδ",
        "έΦΡ",
        "έΦΦ",
        "έΦ┤",
        "έΦυ",
        "έΦε",
        "έΦΑ",
        "έΦ╝",
        "έΧη",
        "έΧθ",
        "έΧγ",
        "έΧΦ",
        "έΧσ",
        "έΧο",
        "έΧι",
        "έΧΡ",
        "έΧυ",
        "έΧπ",
        "έΧρ",
        "έΧν",
        "έΧξ",
        "έΧβ",
        "έΧα",
        "έΧΤ",
        "έΧΥ",
        "έΧτ",
        "έΧς",
        "έΦα",
        "έΦΝ",
        "έΨΙ",
        "έΨΕ",
        "έΨΝ",
        "έΨΡ",
        "έΨΑ",
        "╧Κ",
        "╬υ",
        "╬φ",
        "╬χ",
        "╧Λ",
        "╬ψ",
        "╧Ν",
        "╧Ξ",
        "╧Μ",
        "╧Ο",
        "╬Η",
        "╬Ι",
        "╬Κ",
        "╬Λ",
        "╬Ν",
        "╬Ο",
        "╬Π",
        "┬▒",
        "έΚξ",
        "έΚν",
        "╬ς",
        "╬τ",
        "├╖",
        "έΚΙ",
        "┬░",
        "έΙβ",
        "┬╖",
        "έΙγ",
        "έΒ┐",
        "┬▓",
        "έΨι",
        "┬ι",
    ],
    "cp775": [
        "─å",
        "├╝",
        "├®",
        "─ü",
        "├ż",
        "─Ż",
        "├ź",
        "─ć",
        "┼é",
        "─ō",
        "┼¢",
        "┼Ś",
        "─½",
        "┼╣",
        "├ä",
        "├ģ",
        "├ē",
        "├”",
        "├å",
        "┼Ź",
        "├Č",
        "─ó",
        "┬ó",
        "┼Ü",
        "┼ø",
        "├¢",
        "├£",
        "├Ė",
        "┬Ż",
        "├ś",
        "├Ś",
        "┬ż",
        "─Ć",
        "─¬",
        "├│",
        "┼╗",
        "┼╝",
        "┼║",
        "ŌĆØ",
        "┬”",
        "┬®",
        "┬«",
        "┬¼",
        "┬Į",
        "┬╝",
        "┼ü",
        "┬½",
        "┬╗",
        "Ō¢æ",
        "Ō¢Æ",
        "Ō¢ō",
        "Ōöé",
        "Ōöż",
        "─ä",
        "─ī",
        "─ś",
        "─¢",
        "ŌĢŻ",
        "ŌĢæ",
        "ŌĢŚ",
        "ŌĢØ",
        "─«",
        "┼Ā",
        "ŌöÉ",
        "Ōöö",
        "Ōö┤",
        "Ōö¼",
        "Ōö£",
        "ŌöĆ",
        "Ōö╝",
        "┼▓",
        "┼¬",
        "ŌĢÜ",
        "ŌĢö",
        "ŌĢ®",
        "ŌĢ”",
        "ŌĢĀ",
        "ŌĢÉ",
        "ŌĢ¼",
        "┼Į",
        "─ģ",
        "─Ź",
        "─Ö",
        "─Ś",
        "─»",
        "┼Ī",
        "┼│",
        "┼½",
        "┼Š",
        "Ōöś",
        "Ōöī",
        "Ō¢ł",
        "Ō¢ä",
        "Ō¢ī",
        "Ō¢É",
        "Ō¢Ć",
        "├ō",
        "├¤",
        "┼ī",
        "┼ā",
        "├Ą",
        "├Ģ",
        "┬Ą",
        "┼ä",
        "─Č",
        "─Ę",
        "─╗",
        "─╝",
        "┼å",
        "─Æ",
        "┼ģ",
        "ŌĆÖ",
        "┬Ł",
        "┬▒",
        "ŌĆ£",
        "┬Š",
        "┬Č",
        "┬¦",
        "├Ę",
        "ŌĆ×",
        "┬░",
        "ŌłÖ",
        "┬Ę",
        "┬╣",
        "┬│",
        "┬▓",
        "Ō¢Ā",
        "┬Ā",
    ],
    "cp850": [
        "├ç",
        "├╝",
        "├®",
        "├ó",
        "├ñ",
        "├á",
        "├Ñ",
        "├º",
        "├¬",
        "├½",
        "├¿",
        "├»",
        "├«",
        "├¼",
        "├ä",
        "├à",
        "├ë",
        "├ª",
        "├å",
        "├┤",
        "├Â",
        "├▓",
        "├╗",
        "├╣",
        "├┐",
        "├û",
        "├£",
        "├©",
        "┬ú",
        "├ÿ",
        "├ù",
        "ãÆ",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├æ",
        "┬¬",
        "┬║",
        "┬┐",
        "┬«",
        "┬¼",
        "┬¢",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "Ôûæ",
        "ÔûÆ",
        "Ôûô",
        "Ôöé",
        "Ôöñ",
        "├ü",
        "├é",
        "├Ç",
        "┬®",
        "Ôòú",
        "Ôòæ",
        "Ôòù",
        "ÔòØ",
        "┬ó",
        "┬Ñ",
        "ÔöÉ",
        "Ôöö",
        "Ôö┤",
        "Ôö¼",
        "Ôö£",
        "ÔöÇ",
        "Ôö╝",
        "├ú",
        "├â",
        "ÔòÜ",
        "Ôòö",
        "Ôò®",
        "Ôòª",
        "Ôòá",
        "ÔòÉ",
        "Ôò¼",
        "┬ñ",
        "├░",
        "├É",
        "├è",
        "├ï",
        "├ê",
        "─▒",
        "├ì",
        "├Ä",
        "├Å",
        "Ôöÿ",
        "Ôöî",
        "Ôûê",
        "Ôûä",
        "┬ª",
        "├î",
        "ÔûÇ",
        "├ô",
        "├ƒ",
        "├ö",
        "├Æ",
        "├Á",
        "├ò",
        "┬Á",
        "├¥",
        "├×",
        "├Ü",
        "├ø",
        "├Ö",
        "├¢",
        "├Ø",
        "┬»",
        "┬┤",
        "┬¡",
        "┬▒",
        "ÔÇù",
        "┬¥",
        "┬Â",
        "┬º",
        "├À",
        "┬©",
        "┬░",
        "┬¿",
        "┬À",
        "┬╣",
        "┬│",
        "┬▓",
        "Ôûá",
        "┬á",
    ],
    "cp852": [
        "├ç",
        "├╝",
        "├ę",
        "├ó",
        "├Ą",
        "┼»",
        "─ç",
        "├ž",
        "┼é",
        "├ź",
        "┼É",
        "┼Ĺ",
        "├«",
        "┼╣",
        "├ä",
        "─ć",
        "├ë",
        "─╣",
        "─║",
        "├┤",
        "├Â",
        "─Ż",
        "─ż",
        "┼Ü",
        "┼Ť",
        "├ľ",
        "├ť",
        "┼Ą",
        "┼ą",
        "┼ü",
        "├Ś",
        "─Ź",
        "├í",
        "├ş",
        "├│",
        "├║",
        "─ä",
        "─ů",
        "┼Ż",
        "┼ż",
        "─ś",
        "─Ö",
        "┬Č",
        "┼║",
        "─î",
        "┼č",
        "┬ź",
        "┬╗",
        "ÔľĹ",
        "Ôľĺ",
        "Ôľô",
        "Ôöé",
        "ÔöĄ",
        "├ü",
        "├é",
        "─Ü",
        "┼×",
        "ÔĽú",
        "ÔĽĹ",
        "ÔĽŚ",
        "ÔĽŁ",
        "┼╗",
        "┼╝",
        "ÔöÉ",
        "Ôöö",
        "Ôö┤",
        "ÔöČ",
        "Ôöť",
        "ÔöÇ",
        "Ôö╝",
        "─é",
        "─â",
        "ÔĽÜ",
        "ÔĽö",
        "ÔĽę",
        "ÔĽŽ",
        "ÔĽá",
        "ÔĽÉ",
        "ÔĽČ",
        "┬Ą",
        "─Ĺ",
        "─É",
        "─Ä",
        "├ő",
        "─Ć",
        "┼ç",
        "├Ź",
        "├Ä",
        "─Ť",
        "Ôöś",
        "Ôöî",
        "Ôľł",
        "Ôľä",
        "┼ó",
        "┼«",
        "ÔľÇ",
        "├ô",
        "├č",
        "├ö",
        "┼â",
        "┼ä",
        "┼ł",
        "┼á",
        "┼í",
        "┼ö",
        "├Ü",
        "┼Ľ",
        "┼░",
        "├Ż",
        "├Ł",
        "┼ú",
        "┬┤",
        "┬ş",
        "╦Ł",
        "╦Ť",
        "╦ç",
        "╦ś",
        "┬ž",
        "├Ě",
        "┬Ş",
        "┬░",
        "┬Ę",
        "╦Ö",
        "┼▒",
        "┼ś",
        "┼Ö",
        "Ôľá",
        "┬á",
    ],
    "cp855": [
        "Лњ",
        "лѓ",
        "ЛЊ",
        "лЃ",
        "ЛЉ",
        "лЂ",
        "Лћ",
        "лё",
        "ЛЋ",
        "лЁ",
        "Лќ",
        "лє",
        "ЛЌ",
        "лЄ",
        "Лў",
        "лѕ",
        "ЛЎ",
        "лЅ",
        "Лџ",
        "лі",
        "ЛЏ",
        "лІ",
        "Лю",
        "лї",
        "Лъ",
        "лј",
        "ЛЪ",
        "лЈ",
        "Лј",
        "л«",
        "Лі",
        "лф",
        "л░",
        "лљ",
        "л▒",
        "лЉ",
        "Лє",
        "лд",
        "л┤",
        "лћ",
        "лх",
        "лЋ",
        "Лё",
        "лц",
        "л│",
        "лЊ",
        "┬Ф",
        "┬╗",
        "РќЉ",
        "Рќњ",
        "РќЊ",
        "Рћѓ",
        "Рћц",
        "ЛЁ",
        "лЦ",
        "лИ",
        "лў",
        "РЋБ",
        "РЋЉ",
        "РЋЌ",
        "РЋЮ",
        "л╣",
        "лЎ",
        "Рћљ",
        "Рћћ",
        "Рћ┤",
        "Рћг",
        "Рћю",
        "Рћђ",
        "Рћ╝",
        "л║",
        "лџ",
        "РЋџ",
        "РЋћ",
        "РЋЕ",
        "РЋд",
        "РЋа",
        "РЋљ",
        "РЋг",
        "┬ц",
        "л╗",
        "лЏ",
        "л╝",
        "лю",
        "лй",
        "лЮ",
        "лЙ",
        "лъ",
        "л┐",
        "Рћў",
        "Рћї",
        "Рќѕ",
        "Рќё",
        "лЪ",
        "ЛЈ",
        "Рќђ",
        "л»",
        "Лђ",
        "ла",
        "ЛЂ",
        "лА",
        "Лѓ",
        "лб",
        "ЛЃ",
        "лБ",
        "лХ",
        "лќ",
        "л▓",
        "лњ",
        "Лї",
        "лг",
        "Рёќ",
        "┬Г",
        "ЛІ",
        "лФ",
        "ли",
        "лЌ",
        "Лѕ",
        "ле",
        "ЛЇ",
        "лГ",
        "ЛЅ",
        "лЕ",
        "ЛЄ",
        "лД",
        "┬Д",
        "Рќа",
        "┬а",
    ],
    "cp856": [
        "├ק",
        "┬«",
        "┬¼",
        "┬¢",
        "┬╝",
        "┬½",
        "┬╗",
        "┬®",
        "┬»",
        "┬┤",
        "┬▒",
        "┬¥",
        "┬©",
        "┬░",
        "┬╣",
        "┬│",
        "┬▓",
    ],
    "cp857": [
        "├ç",
        "├╝",
        "├®",
        "├ó",
        "├ñ",
        "├á",
        "├Ñ",
        "├ğ",
        "├¬",
        "├½",
        "├¿",
        "├»",
        "├«",
        "─▒",
        "├ä",
        "├à",
        "├ë",
        "├Ğ",
        "├å",
        "├┤",
        "├Â",
        "├▓",
        "├╗",
        "├╣",
        "─░",
        "├û",
        "├£",
        "├©",
        "┬ú",
        "├İ",
        "┼Ş",
        "┼ş",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├æ",
        "─Ş",
        "─ş",
        "┬┐",
        "┬«",
        "┬¼",
        "┬¢",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "Ôûæ",
        "ÔûÆ",
        "Ôûô",
        "Ôöé",
        "Ôöñ",
        "├ü",
        "├é",
        "├Ç",
        "┬®",
        "Ôòú",
        "Ôòæ",
        "Ôòù",
        "ÔòØ",
        "┬ó",
        "┬Ñ",
        "ÔöÉ",
        "Ôöö",
        "Ôö┤",
        "Ôö¼",
        "Ôö£",
        "ÔöÇ",
        "Ôö╝",
        "├ú",
        "├â",
        "ÔòÜ",
        "Ôòö",
        "Ôò®",
        "ÔòĞ",
        "Ôòá",
        "ÔòÉ",
        "Ôò¼",
        "┬ñ",
        "┬║",
        "┬¬",
        "├è",
        "├ï",
        "├ê",
        "├ı",
        "├Ä",
        "├Å",
        "Ôöİ",
        "Ôöî",
        "Ôûê",
        "Ôûä",
        "┬Ğ",
        "├î",
        "ÔûÇ",
        "├ô",
        "├ş",
        "├ö",
        "├Æ",
        "├Á",
        "├ò",
        "┬Á",
        "├ù",
        "├Ü",
        "├ø",
        "├Ö",
        "├¼",
        "├┐",
        "┬»",
        "┬┤",
        "┬¡",
        "┬▒",
        "┬¥",
        "┬Â",
        "┬ğ",
        "├À",
        "┬©",
        "┬░",
        "┬¿",
        "┬À",
        "┬╣",
        "┬│",
        "┬▓",
        "Ôûá",
        "┬á",
    ],
    "cp858": [
        "├ç",
        "├╝",
        "├®",
        "├ó",
        "├ñ",
        "├á",
        "├Ñ",
        "├º",
        "├¬",
        "├½",
        "├¿",
        "├»",
        "├«",
        "├¼",
        "├ä",
        "├à",
        "├ë",
        "├ª",
        "├å",
        "├┤",
        "├Â",
        "├▓",
        "├╗",
        "├╣",
        "├┐",
        "├û",
        "├£",
        "├©",
        "┬ú",
        "├ÿ",
        "├ù",
        "ãÆ",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├æ",
        "┬¬",
        "┬║",
        "┬┐",
        "┬«",
        "┬¼",
        "┬¢",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "Ôûæ",
        "ÔûÆ",
        "Ôûô",
        "Ôöé",
        "Ôöñ",
        "├ü",
        "├é",
        "├Ç",
        "┬®",
        "Ôòú",
        "Ôòæ",
        "Ôòù",
        "ÔòØ",
        "┬ó",
        "┬Ñ",
        "ÔöÉ",
        "Ôöö",
        "Ôö┤",
        "Ôö¼",
        "Ôö£",
        "ÔöÇ",
        "Ôö╝",
        "├ú",
        "├â",
        "ÔòÜ",
        "Ôòö",
        "Ôò®",
        "Ôòª",
        "Ôòá",
        "ÔòÉ",
        "Ôò¼",
        "┬ñ",
        "├░",
        "├É",
        "├è",
        "├ï",
        "├ê",
        "Ôé¼",
        "├ì",
        "├Ä",
        "├Å",
        "Ôöÿ",
        "Ôöî",
        "Ôûê",
        "Ôûä",
        "┬ª",
        "├î",
        "ÔûÇ",
        "├ô",
        "├ƒ",
        "├ö",
        "├Æ",
        "├Á",
        "├ò",
        "┬Á",
        "├¥",
        "├×",
        "├Ü",
        "├ø",
        "├Ö",
        "├¢",
        "├Ø",
        "┬»",
        "┬┤",
        "┬¡",
        "┬▒",
        "ÔÇù",
        "┬¥",
        "┬Â",
        "┬º",
        "├À",
        "┬©",
        "┬░",
        "┬¿",
        "┬À",
        "┬╣",
        "┬│",
        "┬▓",
        "Ôûá",
        "┬á",
    ],
    "cp860": [
        "├ç",
        "├╝",
        "├Ò",
        "├ó",
        "├ú",
        "├á",
        "├ü",
        "├º",
        "├¬",
        "├è",
        "├¿",
        "├ì",
        "├õ",
        "├¼",
        "├â",
        "├é",
        "├Ê",
        "├Ç",
        "├ê",
        "├┤",
        "├╡",
        "├▓",
        "├Ü",
        "├╣",
        "├Ô",
        "├ò",
        "├£",
        "┬ó",
        "┬ú",
        "├Õ",
        "Γéº",
        "├ô",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├À",
        "┬¬",
        "┬║",
        "┬┐",
        "├È",
        "┬¼",
        "┬╜",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "ΓÚÀ",
        "ΓÚÈ",
        "ΓÚô",
        "Γõé",
        "Γõñ",
        "Γòí",
        "Γòó",
        "ΓòÚ",
        "Γòò",
        "Γòú",
        "ΓòÀ",
        "Γòù",
        "ΓòÙ",
        "Γò£",
        "Γò¢",
        "ΓõÉ",
        "Γõõ",
        "Γõ┤",
        "Γõ¼",
        "Γõ£",
        "ΓõÇ",
        "Γõ╝",
        "Γò₧",
        "ΓòÓ",
        "ΓòÜ",
        "Γòõ",
        "ΓòÒ",
        "Γòª",
        "Γòá",
        "ΓòÉ",
        "Γò¼",
        "Γòº",
        "Γò¿",
        "Γòñ",
        "ΓòÑ",
        "ΓòÕ",
        "ΓòÌ",
        "ΓòÈ",
        "Γòô",
        "Γò½",
        "Γò¬",
        "ΓõÌ",
        "ΓõÔ",
        "ΓÚê",
        "ΓÚã",
        "ΓÚÔ",
        "ΓÚÉ",
        "ΓÚÇ",
        "╬▒",
        "├Ó",
        "╬ô",
        "╧Ç",
        "╬ú",
        "╧â",
        "┬╡",
        "╧ã",
        "╬ª",
        "╬Ì",
        "╬Ò",
        "╬┤",
        "Γê₧",
        "╧Á",
        "╬╡",
        "ΓêÒ",
        "ΓÊí",
        "┬▒",
        "ΓÊÑ",
        "ΓÊñ",
        "ΓÔá",
        "ΓÔí",
        "├╖",
        "ΓÊê",
        "┬░",
        "ΓêÕ",
        "┬╖",
        "ΓêÜ",
        "Γü┐",
        "┬▓",
        "ΓÚá",
        "┬á",
    ],
    "cp861": [
        "├ç",
        "├╝",
        "├⌐",
        "├ó",
        "├Á",
        "├á",
        "├Í",
        "├Ú",
        "├¬",
        "├½",
        "├¿",
        "├É",
        "├░",
        "├₧",
        "├ä",
        "├à",
        "├ë",
        "├Ó",
        "├å",
        "├┤",
        "├╢",
        "├╛",
        "├╗",
        "├Ø",
        "├╜",
        "├û",
        "├£",
        "├╕",
        "┬ú",
        "├ý",
        "ΓéÚ",
        "╞Æ",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├ü",
        "├Þ",
        "├ô",
        "├Ü",
        "┬┐",
        "ΓðÉ",
        "┬¼",
        "┬╜",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "Γûæ",
        "ΓûÆ",
        "Γûô",
        "Γöé",
        "ΓöÁ",
        "Γþí",
        "Γþó",
        "Γþû",
        "Γþþ",
        "Γþú",
        "Γþæ",
        "ΓþÝ",
        "ΓþØ",
        "Γþ£",
        "Γþø",
        "ΓöÉ",
        "Γöö",
        "Γö┤",
        "Γö¼",
        "Γö£",
        "ΓöÇ",
        "Γö╝",
        "Γþ₧",
        "Γþƒ",
        "ΓþÜ",
        "Γþö",
        "Γþ⌐",
        "ΓþÓ",
        "Γþá",
        "ΓþÉ",
        "Γþ¼",
        "ΓþÚ",
        "Γþ¿",
        "ΓþÁ",
        "ΓþÍ",
        "ΓþÖ",
        "Γþý",
        "ΓþÆ",
        "Γþô",
        "Γþ½",
        "Γþ¬",
        "Γöý",
        "Γöð",
        "Γûê",
        "Γûä",
        "Γûð",
        "ΓûÉ",
        "ΓûÇ",
        "╬▒",
        "├ƒ",
        "╬ô",
        "╧Ç",
        "╬ú",
        "╧â",
        "┬╡",
        "╧ä",
        "╬Ó",
        "╬ý",
        "╬⌐",
        "╬┤",
        "Γê₧",
        "╧å",
        "╬╡",
        "Γê⌐",
        "Γëí",
        "┬▒",
        "ΓëÍ",
        "ΓëÁ",
        "Γðá",
        "Γðí",
        "├╖",
        "Γëê",
        "┬░",
        "ΓêÖ",
        "┬╖",
        "ΓêÜ",
        "Γü┐",
        "┬▓",
        "Γûá",
        "┬á",
    ],
    "cp862": [
        "╫נ",
        "╫ס",
        "╫ע",
        "╫ף",
        "╫פ",
        "╫ץ",
        "╫צ",
        "╫ק",
        "╫ר",
        "╫ש",
        "╫ת",
        "╫¢",
        "╫£",
        "╫¥",
        "╫₧",
        "╫ƒ",
        "╫á",
        "╫í",
        "╫ó",
        "╫ú",
        "╫ñ",
        "╫Ñ",
        "╫ª",
        "╫º",
        "╫¿",
        "╫⌐",
        "╫¬",
        "┬ó",
        "┬ú",
        "┬Ñ",
        "Γגº",
        "╞ע",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├ס",
        "┬¬",
        "┬║",
        "┬┐",
        "Γלנ",
        "┬¼",
        "┬╜",
        "┬╝",
        "┬í",
        "┬½",
        "┬╗",
        "Γצס",
        "Γצע",
        "Γצף",
        "Γפג",
        "Γפñ",
        "Γץí",
        "Γץó",
        "Γץצ",
        "Γץץ",
        "Γץú",
        "Γץס",
        "Γץק",
        "Γץ¥",
        "Γץ£",
        "Γץ¢",
        "Γפנ",
        "Γפפ",
        "Γפ┤",
        "Γפ¼",
        "Γפ£",
        "Γפא",
        "Γפ╝",
        "Γץ₧",
        "Γץƒ",
        "Γץת",
        "Γץפ",
        "Γץ⌐",
        "Γץª",
        "Γץá",
        "Γץנ",
        "Γץ¼",
        "Γץº",
        "Γץ¿",
        "Γץñ",
        "ΓץÑ",
        "Γץש",
        "Γץר",
        "Γץע",
        "Γץף",
        "Γץ½",
        "Γץ¬",
        "Γפר",
        "Γפל",
        "Γצט",
        "Γצה",
        "Γצל",
        "Γצנ",
        "Γצא",
        "╬▒",
        "├ƒ",
        "╬ף",
        "╧א",
        "╬ú",
        "╧ד",
        "┬╡",
        "╧ה",
        "╬ª",
        "╬ר",
        "╬⌐",
        "╬┤",
        "Γט₧",
        "╧ז",
        "╬╡",
        "Γט⌐",
        "Γיí",
        "┬▒",
        "ΓיÑ",
        "Γיñ",
        "Γלá",
        "Γלí",
        "├╖",
        "Γיט",
        "┬░",
        "Γטש",
        "┬╖",
        "Γטת",
        "Γב┐",
        "┬▓",
        "Γצá",
        "┬á",
    ],
    "cp863": [
        "├ç",
        "├╝",
        "├⌐",
        "├ó",
        "├é",
        "├¦",
        "┬╢",
        "├¯",
        "├¬",
        "├½",
        "├Î",
        "├»",
        "├«",
        "ΓÇù",
        "├Ç",
        "┬¯",
        "├ë",
        "├ê",
        "├è",
        "├┤",
        "├ï",
        "├§",
        "├╗",
        "├╣",
        "┬¨",
        "├Ë",
        "├£",
        "┬ó",
        "┬ú",
        "├Ô",
        "├¢",
        "╞Ê",
        "┬³",
        "┬┤",
        "├│",
        "├║",
        "┬Î",
        "┬╕",
        "┬│",
        "┬»",
        "├À",
        "ΓîÉ",
        "┬¼",
        "┬╜",
        "┬╝",
        "┬╛",
        "┬½",
        "┬╗",
        "ΓûÈ",
        "ΓûÊ",
        "Γûô",
        "ΓËé",
        "ΓË¨",
        "ΓÏ´",
        "ΓÏó",
        "ΓÏû",
        "ΓÏÏ",
        "ΓÏú",
        "ΓÏÈ",
        "ΓÏù",
        "ΓÏÙ",
        "ΓÏ£",
        "ΓÏ¢",
        "ΓËÉ",
        "ΓËË",
        "ΓË┤",
        "ΓË¼",
        "ΓË£",
        "ΓËÇ",
        "ΓË╝",
        "ΓÏÛ",
        "ΓÏƒ",
        "ΓÏÜ",
        "ΓÏË",
        "ΓÏ⌐",
        "ΓÏ³",
        "ΓÏ¦",
        "ΓÏÉ",
        "ΓÏ¼",
        "ΓÏ¯",
        "ΓÏÎ",
        "ΓÏ¨",
        "ΓÏ¸",
        "ΓÏÔ",
        "ΓÏ¤",
        "ΓÏÊ",
        "ΓÏô",
        "ΓÏ½",
        "ΓÏ¬",
        "ΓË¤",
        "ΓËî",
        "Γûê",
        "ΓûÂ",
        "Γûî",
        "ΓûÉ",
        "ΓûÇ",
        "╬▒",
        "├ƒ",
        "╬ô",
        "╧Ç",
        "╬ú",
        "╧â",
        "┬╡",
        "╧Â",
        "╬³",
        "╬¤",
        "╬⌐",
        "╬┤",
        "ΓêÛ",
        "╧¶",
        "╬╡",
        "Γê⌐",
        "Γë´",
        "┬▒",
        "Γë¸",
        "Γë¨",
        "Γî¦",
        "Γî´",
        "├╖",
        "Γëê",
        "┬░",
        "ΓêÔ",
        "┬╖",
        "ΓêÜ",
        "Γü┐",
        "┬▓",
        "Γû¦",
        "┬¦",
    ],
    "cp864": [
        "ﺁ٠",
        "ﺁ٧",
        "ﻗ┤ﻷ",
        "ﻗ┤ﻸ",
        "ﻗ≈φ",
        "ﻗ½°",
        "ﻗ½∙",
        "ﻗ½ﺱ",
        "ﻗ½¤",
        "ﻗ½،",
        "ﻗ½٤",
        "ﻗ½β",
        "ﻗ½┐",
        "ﻗ½½",
        "ﻗ½»",
        "ﺧ٢",
        "ﻗ┤ﻼ",
        "ﺩ│",
        "ﺁ١",
        "ﺁﺵ",
        "ﺁﺱ",
        "ﻗ┬┤",
        "ﺁﺙ",
        "ﺁ؛",
        "ﻡ؛٧",
        "ﻡ؛٨",
        "ﻡ؛؛",
        "ﻡ؛ﺱ",
        "ﺁ\xa0",
        "ﺁﺝ",
        "ﻡﻑ∙",
        "ﺁ£",
        "ﺁ¤",
        "ﻡﻑ▒",
        "ﻡﻑ└",
        "ﻡﻑ┘",
        "ﻡﻑ¼",
        "ﻡﻑﻷ",
        "ﻅ┐",
        "ﻡﻑﻻ",
        "ﻡﻑ\xad",
        "ﻡﻑﺄ",
        "ﻋ\xa0",
        "ﻋ\xad",
        "ﻋﺂ",
        "ﻋ£",
        "ﻋ¤",
        "ﻋﺄ",
        "ﻋﺎ",
        "ﻋﺏ",
        "ﻡ؛∞",
        "ﻡﻑ١",
        "ﻡﻑ٥",
        "ﻡﻑ٩",
        "ﺁﺂ",
        "ﻡﻑ°",
        "ﻡﻑ·",
        "ﻡﻑ√",
        "ﻡﻑ─",
        "ﻡ؛├",
        "ﻡﻑ┴",
        "ﻡﻑ┌",
        "ﻡﻑ∞",
        "ﻡﻑ±",
        "ﻡﻑ«",
        "ﻡﻑ£",
        "ﻡﻑﺏ",
        "ﻡﻑﺙ",
        "ﻡﻑﺝ",
        "ﻡﻑﺥ",
        "ﻡﻑ٣",
        "ﻡﻑ٧",
        "ﻡﻑ؛",
        "ﻡﻑ؟",
        "ﻡ؛·",
        "ﻡ؛─",
        "ﻡ؛┴",
        "ﻡ؛┘",
        "ﺁ،",
        "ﺃ٧",
        "ﺃ«",
        "ﻡ؛┬",
        "ﻋ°",
        "ﻡ؛±",
        "ﻡ؛«",
        "ﻡ؛£",
        "ﻡ؛ﺙ",
        "ﻡ؛ﺝ",
        "ﻡ؛ﺥ",
        "ﻡ؛٣",
        "ﻡﻑﺵ",
        "ﻡ؛┐",
        "ﻡ؛└",
        "ﻡ؛┌",
        "ﻡ؛\xad",
        "ﻡ٩ﺵ",
        "ﻋ∞",
        "ﻡ؛ﺄ",
        "ﻡ؛ﺏ",
        "ﻡ؛،",
        "ﻡ؛٠",
        "ﻡ؛٢",
        "ﻡ؛β",
        "ﻡ؛¼",
        "ﻡ؛٥",
        "ﻡ؛٦",
        "ﻡ؛ﻻ",
        "ﻡ؛ﻷ",
        "ﻡ؛١",
        "ﻗ≈\xa0",
    ],
    "cp865": [
        "├ç",
        "├╝",
        "├⌐",
        "├ó",
        "├ñ",
        "├á",
        "├Ñ",
        "├º",
        "├¬",
        "├½",
        "├¿",
        "├¤",
        "├«",
        "├¼",
        "├ä",
        "├à",
        "├ë",
        "├ª",
        "├å",
        "├┤",
        "├╢",
        "├▓",
        "├╗",
        "├╣",
        "├┐",
        "├û",
        "├£",
        "├╕",
        "┬ú",
        "├ÿ",
        "Γéº",
        "╞Æ",
        "├í",
        "├¡",
        "├│",
        "├║",
        "├▒",
        "├æ",
        "┬¬",
        "┬║",
        "┬┐",
        "ΓîÉ",
        "┬¼",
        "┬╜",
        "┬╝",
        "┬í",
        "┬½",
        "┬ñ",
        "Γûæ",
        "ΓûÆ",
        "Γûô",
        "Γöé",
        "Γöñ",
        "Γòí",
        "Γòó",
        "Γòû",
        "Γòò",
        "Γòú",
        "Γòæ",
        "Γòù",
        "ΓòØ",
        "Γò£",
        "Γòø",
        "ΓöÉ",
        "Γöö",
        "Γö┤",
        "Γö¼",
        "Γö£",
        "ΓöÇ",
        "Γö╝",
        "Γò₧",
        "Γòƒ",
        "ΓòÜ",
        "Γòö",
        "Γò⌐",
        "Γòª",
        "Γòá",
        "ΓòÉ",
        "Γò¼",
        "Γòº",
        "Γò¿",
        "Γòñ",
        "ΓòÑ",
        "ΓòÖ",
        "Γòÿ",
        "ΓòÆ",
        "Γòô",
        "Γò½",
        "Γò¬",
        "Γöÿ",
        "Γöî",
        "Γûê",
        "Γûä",
        "Γûî",
        "ΓûÉ",
        "ΓûÇ",
        "╬▒",
        "├ƒ",
        "╬ô",
        "╧Ç",
        "╬ú",
        "╧â",
        "┬╡",
        "╧ä",
        "╬ª",
        "╬ÿ",
        "╬⌐",
        "╬┤",
        "Γê₧",
        "╧å",
        "╬╡",
        "Γê⌐",
        "Γëí",
        "┬▒",
        "ΓëÑ",
        "Γëñ",
        "Γîá",
        "Γîí",
        "├╖",
        "Γëê",
        "┬░",
        "ΓêÖ",
        "┬╖",
        "ΓêÜ",
        "Γü┐",
        "┬▓",
        "Γûá",
        "┬á",
    ],
    "cp866": [
        "╨Р",
        "╨С",
        "╨Т",
        "╨У",
        "╨Ф",
        "╨Х",
        "╨Ц",
        "╨Ч",
        "╨Ш",
        "╨Щ",
        "╨Ъ",
        "╨Ы",
        "╨Ь",
        "╨Э",
        "╨Ю",
        "╨Я",
        "╨а",
        "╨б",
        "╨в",
        "╨г",
        "╨д",
        "╨е",
        "╨ж",
        "╨з",
        "╨и",
        "╨й",
        "╨к",
        "╨л",
        "╨м",
        "╨н",
        "╨о",
        "╨п",
        "╨░",
        "╨▒",
        "╨▓",
        "╨│",
        "╨┤",
        "╨╡",
        "╨╢",
        "╨╖",
        "╨╕",
        "╨╣",
        "╨║",
        "╨╗",
        "╨╝",
        "╨╜",
        "╨╛",
        "╨┐",
        "тЦС",
        "тЦТ",
        "тЦУ",
        "тФВ",
        "тФд",
        "тХб",
        "тХв",
        "тХЦ",
        "тХХ",
        "тХг",
        "тХС",
        "тХЧ",
        "тХЭ",
        "тХЬ",
        "тХЫ",
        "тФР",
        "тФФ",
        "тФ┤",
        "тФм",
        "тФЬ",
        "тФА",
        "тФ╝",
        "тХЮ",
        "тХЯ",
        "тХЪ",
        "тХФ",
        "тХй",
        "тХж",
        "тХа",
        "тХР",
        "тХм",
        "тХз",
        "тХи",
        "тХд",
        "тХе",
        "тХЩ",
        "тХШ",
        "тХТ",
        "тХУ",
        "тХл",
        "тХк",
        "тФШ",
        "тФМ",
        "тЦИ",
        "тЦД",
        "тЦМ",
        "тЦР",
        "тЦА",
        "╤А",
        "╤Б",
        "╤В",
        "╤Г",
        "╤Д",
        "╤Е",
        "╤Ж",
        "╤З",
        "╤И",
        "╤Й",
        "╤К",
        "╤Л",
        "╤М",
        "╤Н",
        "╤О",
        "╤П",
        "╨Б",
        "╤С",
        "╨Д",
        "╤Ф",
        "╨З",
        "╤Ч",
        "╨О",
        "╤Ю",
        "┬░",
        "тИЩ",
        "┬╖",
        "тИЪ",
        "тДЦ",
        "┬д",
        "тЦа",
        "┬а",
    ],
    "cp869": [
        "╬Ά",
        "┬Μ",
        "┬Θ",
        "┬Γ",
        "╬·",
        "╬¬",
        "╬¦",
        "╬Η",
        "╬’",
        "╬―",
        "╬½",
        "┬Ζ",
        "╬Ή",
        "┬▓",
        "┬│",
        "╬Θ",
        "┬ύ",
        "╬Ι",
        "╬«",
        "╬»",
        "Σ¦",
        "╬Ί",
        "Σ’",
        "ΣΈ",
        "╬Ϊ",
        "╬Ό",
        "╬Ύ",
        "╬Ϋ",
        "╬©",
        "┬Ξ",
        "╬Ώ",
        "╬²",
        "┬½",
        "┬╗",
        "θΫΪ",
        "θΫΌ",
        "╬³",
        "╬ά",
        "╬£",
        "╬έ",
        "θΎύ",
        "θΎΪ",
        "θΎ©",
        "θΎέ",
        "╬ή",
        "╬ί",
        "╬ϊ",
        "╬ΐ",
        "θΎ³",
        "θΎΖ",
        "θΎΓ",
        "θΎϊ",
        "θΎΊ",
        "θΎΘ",
        "╬ύ",
        "╬Α",
        "╬Β",
        "╬Γ",
        "╬Δ",
        "╬Ε",
        "╬Ζ",
        "╬▒",
        "╬▓",
        "╬│",
        "θΫ·",
        "╬┤",
        "╬Κ",
        "╬Λ",
        "╬Μ",
        "╬Ν",
        "╬╣",
        "╬║",
        "╬╗",
        "╬╝",
        "╬Ξ",
        "╬Ο",
        "╬┐",
        "┬Ι",
        "┬▒",
        "ΣΆ",
        "┬Δ",
        "Σ·",
        "┬░",
        "┬Ε",
        "Σ¬",
        "Σ‘",
        "╬░",
        "Σ―",
        "θΫϊ",
        "┬ϊ",
    ],
    "cp874": [
        "โ€ฆ",
        "โ€ข",
        "โ€“",
        "โ€”",
        "ย\xa0",
        "เธ…",
        "เธ‘",
        "เธ’",
        "เธ“",
        "เธ”",
        "เธ•",
        "เธ–",
        "เธ—",
        "เธ\xa0",
        "เธก",
        "เธข",
        "เธฃ",
        "เธค",
        "เธฅ",
        "เธฆ",
        "เธง",
        "เธจ",
        "เธฉ",
        "เธช",
        "เธซ",
        "เธฌ",
        "เธญ",
        "เธฎ",
        "เธฏ",
        "เธฐ",
        "เธฑ",
        "เธฒ",
        "เธณ",
        "เธด",
        "เธต",
        "เธถ",
        "เธท",
        "เธธ",
        "เธน",
        "เธบ",
        "เธฟ",
        "เน€",
        "เน…",
        "เน‘",
        "เน’",
        "เน“",
        "เน”",
        "เน•",
        "เน–",
        "เน—",
    ],
    "cp875": [
        "‘e",
        "‘ά",
        "‘έ",
        "‘ή",
        "‘ϊ",
        "‘ί",
        "‘ό",
        "B£",
        "‘ύ",
        "‘ϋ",
        "‘ώ",
        "‘ς",
        "‘τ",
        "‘υ",
        "Bϊ",
        "‘φ",
        "‘χ",
        "‘ψ",
        "―΅",
        "―a",
        "―c",
        "Bt",
        "‘ο",
        "‘π",
        "‘ρ",
        "―α",
        "‘σ",
        "―γ",
        "―δ",
        "―β",
        "―ε",
        "―b",
        "―d",
        "―e",
        "―f",
        "―g",
        "―h",
        "Bπ",
        "―i",
        "‘°",
        "‘£",
        "S΅q",
        "S΅n",
        "Bά",
        "Bφ",
        "‘g",
        "S΅r",
        "Bw",
        "Bέ",
        "Bx",
        "Bξ",
        "Bο",
        "Bή",
        "Bz",
        "Bτ",
        "Bμ",
    ],
    "cp932": ["ﾂ\x80"],
    "cp1006": [
        "ﺡ\x80",
        "ﺡ\x81",
        "ﺡ\x82",
        "ﺡ\x83",
        "ﺡ\x84",
        "ﺡ\x85",
        "ﺡ\x86",
        "ﺡ\x87",
        "ﺡ\x88",
        "ﺡ\x89",
        "ﺡ\x8a",
        "ﺡ\x8b",
        "ﺡ\x8c",
        "ﺡ\x8d",
        "ﺡ\x8e",
        "ﺡ\x8f",
        "ﺡ\x90",
        "ﺡ\x91",
        "ﺡ\x92",
        "ﺡ\x93",
        "ﺡ\x94",
        "ﺡ\x95",
        "ﺡ\x96",
        "ﺡ\x97",
        "ﺡ\x98",
        "ﺡ\x99",
        "ﺡ\x9a",
        "ﺡ\x9b",
        "ﺡ\x9c",
        "ﺡ\x9d",
        "ﺡ\x9e",
        "ﺡ\x9f",
        "ﺡ\xa0",
        "ﻍﺍ",
        "ﻍﺎ",
        "ﻍﺎ",
        "ﻍﺏ",
        "ﻍﺑ",
        "ﻍﭖ",
        "ﻍﭘ",
        "ﻍﺓ",
        "ﻍﺕ",
        "ﻍﺗ",
        "ﻊ\x8c",
        "ﻊ\x9b",
        "ﺡ\xad",
        "ﻊ\x9f",
        "ﺅﭦ\x81",
        "ﺅﭦ\x8d",
        "ﺅﭦ\x8e",
        "ﺅﭦ\x8e",
        "ﺅﭦ\x8f",
        "ﺅﭦ\x91",
        "ﺅ\xad\x96",
        "ﺅ\xad\x98",
        "ﺅﭦ\x93",
        "ﺅﭦ\x95",
        "ﺅﭦ\x97",
        "ﺅ\xad۵",
        "ﺅ\xad۷",
        "ﺅﭦ\x99",
        "ﺅﭦ\x9b",
        "ﺅﭦ\x9d",
        "ﺅﭦ\x9f",
        "ﺅ\xadﭦ",
        "ﺅ\xadﺙ",
        "ﺅﭦ۰",
        "ﺅﭦ۲",
        "ﺅﭦ۴",
        "ﺅﭦ۶",
        "ﺅﭦ۸",
        "ﺅ؟\x84",
        "ﺅﭦ،",
        "ﺅﭦ\xad",
        "ﺅ؟\x8c",
        "ﺅﭦﺁ",
        "ﺅ؟\x8a",
        "ﺅﭦﺎ",
        "ﺅﭦﺏ",
        "ﺅﭦﭖ",
        "ﺅﭦﺓ",
        "ﺅﭦﺗ",
        "ﺅﭦﭨ",
        "ﺅﭦﺛ",
        "ﺅﭦﺟ",
        "ﺅﭨ\x81",
        "ﺅﭨ\x85",
        "ﺅﭨ\x89",
        "ﺅﭨ\x8a",
        "ﺅﭨ\x8b",
        "ﺅﭨ\x8c",
        "ﺅﭨ\x8d",
        "ﺅﭨ\x8e",
        "ﺅﭨ\x8f",
        "ﺅﭨ\x90",
        "ﺅﭨ\x91",
        "ﺅﭨ\x93",
        "ﺅﭨ\x95",
        "ﺅﭨ\x97",
        "ﺅﭨ\x99",
        "ﺅﭨ\x9b",
        "ﺅ؟\x92",
        "ﺅ؟\x94",
        "ﺅﭨ\x9d",
        "ﺅﭨ\x9f",
        "ﺅﭨ\xa0",
        "ﺅﭨ۰",
        "ﺅﭨ۲",
        "ﺅ؟\x9e",
        "ﺅﭨ۴",
        "ﺅﭨ۶",
        "ﺅﭦ\x85",
        "ﺅﭨ\xad",
        "ﺅ؟۵",
        "ﺅ؟۷",
        "ﺅ؟۸",
        "ﺅ؟۹",
        "ﺅﭦ\x80",
        "ﺅﭦ\x89",
        "ﺅﭦ\x8a",
        "ﺅﭦ\x8b",
        "ﺅﭨﺎ",
        "ﺅﭨﺎ",
        "ﺅﭨﺏ",
        "ﺅ؟ﺍ",
        "ﺅ؟؟",
        "ﺅﺗﺙ",
        "ﺅﺗﺛ",
    ],
    "cp1026": [
        "Cq",
        "B¿",
        "B|",
        "Bw",
        "B£",
        "B¢",
        "B¡",
        "B¬",
        "Cw",
        "B½",
        "Cf",
        "Bu",
        "B§",
        "C¶",
        "Bö",
        "B×",
        "B@",
        "Bs",
        "Bt",
        "Bv",
        "B¼",
        "Bz",
        "Bx",
        "B¶",
        "B¯",
        "B¨",
        "B´",
        "B]",
        "B®",
        "By",
        "B©",
        "Cp",
        "Cx",
        "B$",
        "C©",
        "C¥",
        "C·",
        "C§",
        "D¤",
        "B¾",
        "C|",
        "C¾",
        "C¬",
        "C×",
        "C¯",
        "C¼",
        "B¥",
        "Cm",
        "Ck",
        "Cl",
        "Cn",
        "B·",
        "Cº",
        "Cr",
        "Cª",
        "B¤",
    ],
    "cp1125": [
        "╨Р",
        "╨С",
        "╨Т",
        "╨У",
        "╨Ф",
        "╨Х",
        "╨Ц",
        "╨Ч",
        "╨Ш",
        "╨Щ",
        "╨Ъ",
        "╨Ы",
        "╨Ь",
        "╨Э",
        "╨Ю",
        "╨Я",
        "╨а",
        "╨б",
        "╨в",
        "╨г",
        "╨д",
        "╨е",
        "╨ж",
        "╨з",
        "╨и",
        "╨й",
        "╨к",
        "╨л",
        "╨м",
        "╨н",
        "╨о",
        "╨п",
        "╨░",
        "╨▒",
        "╨▓",
        "╨│",
        "╨┤",
        "╨╡",
        "╨╢",
        "╨╖",
        "╨╕",
        "╨╣",
        "╨║",
        "╨╗",
        "╨╝",
        "╨╜",
        "╨╛",
        "╨┐",
        "тЦС",
        "тЦТ",
        "тЦУ",
        "тФВ",
        "тФд",
        "тХб",
        "тХв",
        "тХЦ",
        "тХХ",
        "тХг",
        "тХС",
        "тХЧ",
        "тХЭ",
        "тХЬ",
        "тХЫ",
        "тФР",
        "тФФ",
        "тФ┤",
        "тФм",
        "тФЬ",
        "тФА",
        "тФ╝",
        "тХЮ",
        "тХЯ",
        "тХЪ",
        "тХФ",
        "тХй",
        "тХж",
        "тХа",
        "тХР",
        "тХм",
        "тХз",
        "тХи",
        "тХд",
        "тХе",
        "тХЩ",
        "тХШ",
        "тХТ",
        "тХУ",
        "тХл",
        "тХк",
        "тФШ",
        "тФМ",
        "тЦИ",
        "тЦД",
        "тЦМ",
        "тЦР",
        "тЦА",
        "╤А",
        "╤Б",
        "╤В",
        "╤Г",
        "╤Д",
        "╤Е",
        "╤Ж",
        "╤З",
        "╤И",
        "╤Й",
        "╤К",
        "╤Л",
        "╤М",
        "╤Н",
        "╤О",
        "╤П",
        "╨Б",
        "╤С",
        "╥Р",
        "╥С",
        "╨Д",
        "╤Ф",
        "╨Ж",
        "╤Ц",
        "╨З",
        "╤Ч",
        "┬╖",
        "тИЪ",
        "тДЦ",
        "┬д",
        "тЦа",
        "┬а",
    ],
    "cp1140": [
        "Cq",
        "B¿",
        "B]",
        "C^",
        "C¨",
        "C´",
        "B£",
        "B^",
        "B¡",
        "B[",
        "Cw",
        "B½",
        "Cf",
        "SbÐ",
        "B§",
        "B~",
        "B×",
        "C°",
        "C¸",
        "CÆ",
        "BÞ",
        "Bt",
        "Bv",
        "B¼",
        "Bz",
        "Bx",
        "B¶",
        "B¯",
        "B¨",
        "B´",
        "B®",
        "By",
        "B©",
        "Cp",
        "BÝ",
        "C©",
        "C¶",
        "C¥",
        "C·",
        "C§",
        "B¾",
        "C]",
        "C¯",
        "C¾",
        "C[",
        "C×",
        "C¼",
        "B¥",
        "Cm",
        "Co",
        "Ck",
        "Cl",
        "Cn",
        "B·",
        "Cº",
        "Cæ",
        "Cr",
        "Cª",
        "B€",
    ],
    "cp1250": [
        "â‚¬",
        "â€š",
        "â€ž",
        "â€¦",
        "â€\xa0",
        "â€ˇ",
        "â€°",
        "Ĺ\xa0",
        "â€ą",
        "Ĺš",
        "Ĺ¤",
        "Ĺ˝",
        "Ĺą",
        "â€™",
        "â€ś",
        "â€ť",
        "â€˘",
        "â€“",
        "â€”",
        "â„˘",
        "Ĺˇ",
        "â€ş",
        "Ĺ›",
        "ĹĄ",
        "Ĺľ",
        "Ĺş",
        "Â\xa0",
        "Ë‡",
        "Â¤",
        "Ä„",
        "Â¦",
        "Â§",
        "Â¨",
        "Â©",
        "Ĺž",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Ĺ»",
        "Â°",
        "Â±",
        "Ë›",
        "Ĺ‚",
        "Â´",
        "Âµ",
        "Â¶",
        "Â·",
        "Â¸",
        "Ä…",
        "Ĺź",
        "Â»",
        "Ä˝",
        "Ëť",
        "Äľ",
        "ĹĽ",
        "Ĺ”",
        "Ă‚",
        "Ä‚",
        "Ă„",
        "Äą",
        "Ä†",
        "Ă‡",
        "ÄŚ",
        "Ă‰",
        "Ă‹",
        "Äš",
        "ĂŤ",
        "ĂŽ",
        "ÄŽ",
        "Ĺ‡",
        "Ă“",
        "Ă”",
        "Ă–",
        "Ă—",
        "Ĺ®",
        "Ăš",
        "Ĺ°",
        "Ăś",
        "Ăť",
        "Ĺ˘",
        "Ăź",
        "Ĺ•",
        "Ăˇ",
        "Ă˘",
        "Ă¤",
        "Äş",
        "Ä‡",
        "Ă§",
        "ÄŤ",
        "Ă©",
        "Ä™",
        "Ă«",
        "Ä›",
        "Ă\xad",
        "Ă®",
        "ÄŹ",
        "Ä‘",
        "Ĺ„",
        "Ăł",
        "Ă´",
        "Ĺ‘",
        "Ă¶",
        "Ă·",
        "Ĺ™",
        "ĹŻ",
        "Ăş",
        "Ĺ±",
        "ĂĽ",
        "Ă˝",
        "ĹŁ",
        "Ë™",
    ],
    "cp1251": [
        "Р‚",
        "Рѓ",
        "вЂљ",
        "С“",
        "вЂћ",
        "вЂ¦",
        "вЂ\xa0",
        "вЂЎ",
        "в‚¬",
        "вЂ°",
        "Р‰",
        "вЂ№",
        "РЉ",
        "РЊ",
        "Р‹",
        "РЏ",
        "С’",
        "вЂ™",
        "вЂњ",
        "вЂќ",
        "вЂў",
        "вЂ“",
        "вЂ”",
        "в„ў",
        "С™",
        "вЂє",
        "Сљ",
        "Сњ",
        "С›",
        "Сџ",
        "В\xa0",
        "РЋ",
        "Сћ",
        "Р€",
        "В¤",
        "Тђ",
        "В¦",
        "В§",
        "РЃ",
        "В©",
        "Р„",
        "В«",
        "В¬",
        "В\xad",
        "В®",
        "Р‡",
        "В°",
        "В±",
        "Р†",
        "С–",
        "Т‘",
        "Вµ",
        "В¶",
        "В·",
        "С‘",
        "в„–",
        "С”",
        "В»",
        "Р…",
        "С•",
        "С—",
        "Рђ",
        "Р‘",
        "Р’",
        "Р“",
        "Р”",
        "Р•",
        "Р–",
        "Р—",
        "Р™",
        "Рљ",
        "Р›",
        "Рњ",
        "Рќ",
        "Рћ",
        "Рџ",
        "Р\xa0",
        "РЎ",
        "Рў",
        "РЈ",
        "Р¤",
        "РҐ",
        "Р¦",
        "Р§",
        "РЁ",
        "Р©",
        "РЄ",
        "Р«",
        "Р¬",
        "Р\xad",
        "Р®",
        "РЇ",
        "Р°",
        "Р±",
        "РІ",
        "Рі",
        "Рґ",
        "Рµ",
        "Р¶",
        "Р·",
        "Рё",
        "Р№",
        "Рє",
        "Р»",
        "Рј",
        "РЅ",
        "Рѕ",
        "Рї",
        "СЂ",
        "СЃ",
        "С‚",
        "Сѓ",
        "С„",
        "С…",
        "С†",
        "С‡",
        "С€",
        "С‰",
        "СЉ",
        "С‹",
        "СЊ",
        "СЌ",
        "СЋ",
        "СЏ",
    ],
    "cp1252": [
        "â‚¬",
        "â€š",
        "Æ’",
        "â€ž",
        "â€¦",
        "â€\xa0",
        "â€¡",
        "Ë†",
        "â€°",
        "Å\xa0",
        "â€¹",
        "Å’",
        "Å½",
        "â€˜",
        "â€™",
        "â€œ",
        "â€¢",
        "â€“",
        "â€”",
        "Ëœ",
        "â„¢",
        "Å¡",
        "â€º",
        "Å“",
        "Å¾",
        "Å¸",
        "Â\xa0",
        "Â¡",
        "Â¢",
        "Â£",
        "Â¤",
        "Â¥",
        "Â¦",
        "Â§",
        "Â¨",
        "Â©",
        "Âª",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Â¯",
        "Â°",
        "Â±",
        "Â²",
        "Â³",
        "Â´",
        "Âµ",
        "Â¶",
        "Â·",
        "Â¸",
        "Â¹",
        "Âº",
        "Â»",
        "Â¼",
        "Â½",
        "Â¾",
        "Â¿",
        "Ã€",
        "Ã‚",
        "Ãƒ",
        "Ã„",
        "Ã…",
        "Ã†",
        "Ã‡",
        "Ãˆ",
        "Ã‰",
        "ÃŠ",
        "Ã‹",
        "ÃŒ",
        "ÃŽ",
        "Ã‘",
        "Ã’",
        "Ã“",
        "Ã”",
        "Ã•",
        "Ã–",
        "Ã—",
        "Ã˜",
        "Ã™",
        "Ãš",
        "Ã›",
        "Ãœ",
        "Ãž",
        "ÃŸ",
        "Ã\xa0",
        "Ã¡",
        "Ã¢",
        "Ã£",
        "Ã¤",
        "Ã¥",
        "Ã¦",
        "Ã§",
        "Ã¨",
        "Ã©",
        "Ãª",
        "Ã«",
        "Ã¬",
        "Ã\xad",
        "Ã®",
        "Ã¯",
        "Ã°",
        "Ã±",
        "Ã²",
        "Ã³",
        "Ã´",
        "Ãµ",
        "Ã¶",
        "Ã·",
        "Ã¸",
        "Ã¹",
        "Ãº",
        "Ã»",
        "Ã¼",
        "Ã½",
        "Ã¾",
        "Ã¿",
    ],
    "cp1253": [
        "β‚¬",
        "Ζ’",
        "β€¦",
        "β€\xa0",
        "β€΅",
        "β€°",
        "β€Ή",
        "β€™",
        "β€Ά",
        "β€“",
        "β€”",
        "β„Ά",
        "β€Ί",
        "Β\xa0",
        "Ξ…",
        "Ξ†",
        "Β£",
        "Β¤",
        "Β¥",
        "Β¦",
        "Β§",
        "Β¨",
        "Β©",
        "Β«",
        "Β¬",
        "Β\xad",
        "Β®",
        "β€•",
        "Β°",
        "Β±",
        "Β²",
        "Β³",
        "Ξ„",
        "Βµ",
        "Β¶",
        "Β·",
        "Ξ‰",
        "Β»",
        "Β½",
        "Ξ‘",
        "Ξ’",
        "Ξ“",
        "Ξ”",
        "Ξ•",
        "Ξ–",
        "Ξ—",
        "Ξ™",
        "Ξ›",
        "Ξ\xa0",
        "Ξ΅",
        "Ξ£",
        "Ξ¤",
        "Ξ¥",
        "Ξ¦",
        "Ξ§",
        "Ξ¨",
        "Ξ©",
        "Ξ«",
        "Ξ¬",
        "Ξ\xad",
        "Ξ®",
        "Ξ―",
        "Ξ°",
        "Ξ±",
        "Ξ²",
        "Ξ³",
        "Ξ΄",
        "Ξµ",
        "Ξ¶",
        "Ξ·",
        "ΞΈ",
        "ΞΉ",
        "ΞΊ",
        "Ξ»",
        "ΞΌ",
        "Ξ½",
        "ΞΎ",
        "ΞΏ",
        "Ο€",
        "Ο‚",
        "Οƒ",
        "Ο„",
        "Ο…",
        "Ο†",
        "Ο‡",
        "Ο‰",
        "Ο‹",
    ],
    "cp1254": [
        "â‚¬",
        "â€š",
        "Æ’",
        "â€¦",
        "â€\xa0",
        "â€¡",
        "Ë†",
        "â€°",
        "Å\xa0",
        "â€¹",
        "Å’",
        "â€˜",
        "â€™",
        "â€œ",
        "â€¢",
        "â€“",
        "â€”",
        "Ëœ",
        "â„¢",
        "Å¡",
        "â€º",
        "Å“",
        "Å¸",
        "Â\xa0",
        "Â¡",
        "Â¢",
        "Â£",
        "Â¤",
        "Â¥",
        "Â¦",
        "Â§",
        "Â¨",
        "Â©",
        "Âª",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Â¯",
        "Â°",
        "Â±",
        "Â²",
        "Â³",
        "Â´",
        "Âµ",
        "Â¶",
        "Â·",
        "Â¸",
        "Â¹",
        "Âº",
        "Â»",
        "Â¼",
        "Â½",
        "Â¾",
        "Â¿",
        "Ã€",
        "Ã‚",
        "Ãƒ",
        "Ã„",
        "Ã…",
        "Ã†",
        "Ã‡",
        "Ãˆ",
        "Ã‰",
        "ÃŠ",
        "Ã‹",
        "ÃŒ",
        "Ã‘",
        "Ã’",
        "Ã“",
        "Ã”",
        "Ã•",
        "Ã–",
        "Ã—",
        "Ã˜",
        "Ã™",
        "Ãš",
        "Ã›",
        "Ãœ",
        "Ä°",
        "ÃŸ",
        "Ã\xa0",
        "Ã¡",
        "Ã¢",
        "Ã£",
        "Ã¤",
        "Ã¥",
        "Ã¦",
        "Ã§",
        "Ã¨",
        "Ã©",
        "Ãª",
        "Ã«",
        "Ã¬",
        "Ã\xad",
        "Ã®",
        "Ã¯",
        "ÄŸ",
        "Ã±",
        "Ã²",
        "Ã³",
        "Ã´",
        "Ãµ",
        "Ã¶",
        "Ã·",
        "Ã¸",
        "Ã¹",
        "Ãº",
        "Ã»",
        "Ã¼",
        "Ä±",
        "ÅŸ",
        "Ã¿",
    ],
    "cp1255": [
        "ג‚¬",
        "ֶ’",
        "ג€¦",
        "ג€\xa0",
        "ג€¡",
        "ֻ†",
        "ג€°",
        "ג€¹",
        "ג€˜",
        "ג€™",
        "ג€¢",
        "ג€“",
        "ג€”",
        "ג„¢",
        "ג€÷",
        "ֲ\xa0",
        "ֲ¡",
        "ֲ¢",
        "ֲ£",
        "ג‚×",
        "ֲ¥",
        "ֲ¦",
        "ֲ§",
        "ֲ¨",
        "ֲ©",
        "ֳ—",
        "ֲ«",
        "ֲ¬",
        "ֲ\xad",
        "ֲ®",
        "ֲ¯",
        "ֲ°",
        "ֲ±",
        "ֲ²",
        "ֲ³",
        "ֲ´",
        "ֲµ",
        "ֲ¶",
        "ֲ·",
        "ֲ¸",
        "ֲ¹",
        "ֳ·",
        "ֲ»",
        "ֲ¼",
        "ֲ½",
        "ֲ¾",
        "ֲ¿",
        "ײ°",
        "ײ±",
        "ײ²",
        "ײ³",
        "ײ´",
        "ײµ",
        "ײ¶",
        "ײ·",
        "ײ¸",
        "ײ¹",
        "ײ»",
        "ײ¼",
        "ײ½",
        "ײ¾",
        "ײ¿",
        "׳€",
        "׳‚",
        "׳ƒ",
        "׳°",
        "׳±",
        "׳²",
        "׳³",
        "׳´",
        "׳‘",
        "׳’",
        "׳“",
        "׳”",
        "׳•",
        "׳–",
        "׳—",
        "׳˜",
        "׳™",
        "׳›",
        "׳\xa0",
        "׳¡",
        "׳¢",
        "׳£",
        "׳₪",
        "׳¥",
        "׳¦",
        "׳§",
        "׳¨",
        "׳©",
        "׳×",
    ],
    "cp1256": [
        "â‚¬",
        "ظ¾",
        "â€ڑ",
        "ئ’",
        "â€\u200d",
        "â€¦",
        "â€\xa0",
        "â€،",
        "ث†",
        "â€°",
        "ظ¹",
        "â€¹",
        "إ’",
        "ع†",
        "عک",
        "عˆ",
        "ع¯",
        "â€ک",
        "â€™",
        "â€œ",
        "â€\u200c",
        "â€¢",
        "â€“",
        "â€”",
        "ع©",
        "â„¢",
        "ع‘",
        "â€؛",
        "إ“",
        "â€Œ",
        "â€چ",
        "ع؛",
        "آ\xa0",
        "طŒ",
        "آ¢",
        "آ£",
        "آ¤",
        "آ¥",
        "آ¦",
        "آ§",
        "آ¨",
        "آ©",
        "ع¾",
        "آ«",
        "آ¬",
        "آ\xad",
        "آ®",
        "آ¯",
        "آ°",
        "آ±",
        "آ²",
        "آ³",
        "آ´",
        "آµ",
        "آ¶",
        "آ·",
        "آ¸",
        "آ¹",
        "ط›",
        "آ»",
        "آ¼",
        "آ½",
        "آ¾",
        "طں",
        "غپ",
        "ط،",
        "ط¢",
        "ط£",
        "ط¤",
        "ط¥",
        "ط¦",
        "ط§",
        "ط¨",
        "ط©",
        "طھ",
        "ط«",
        "ط¬",
        "ط\xad",
        "ط®",
        "ط¯",
        "ط°",
        "ط±",
        "ط²",
        "ط³",
        "ط´",
        "طµ",
        "ط¶",
        "أ—",
        "ط·",
        "ط¸",
        "ط¹",
        "ط؛",
        "ظ€",
        "ظپ",
        "ظ‚",
        "ظƒ",
        "أ\xa0",
        "ظ„",
        "أ¢",
        "ظ…",
        "ظ†",
        "ظ‡",
        "ظˆ",
        "أ§",
        "أ¨",
        "أ©",
        "أھ",
        "أ«",
        "ظ‰",
        "ظٹ",
        "أ®",
        "أ¯",
        "ظ‹",
        "ظŒ",
        "ظچ",
        "ظژ",
        "أ´",
        "ظڈ",
        "ظگ",
        "أ·",
        "ظ‘",
        "أ¹",
        "ظ’",
        "أ»",
        "أ¼",
        "â€ژ",
        "â€ڈ",
        "غ’",
    ],
    "cp1257": [
        "ā‚¬",
        "ā€˛",
        "ā€¦",
        "ā€\xa0",
        "ā€°",
        "ā€¹",
        "ĀØ",
        "Ė‡",
        "Āø",
        "ā€™",
        "ā€¯",
        "ā€¢",
        "ā€“",
        "ā€”",
        "ā„¢",
        "ā€ŗ",
        "ĀÆ",
        "Ė›",
        "Ā\xa0",
        "Ā¢",
        "Ā£",
        "Ā¤",
        "Ā¦",
        "Ā§",
        "Ā©",
        "Å–",
        "Ā«",
        "Ā¬",
        "Ā\xad",
        "Ā®",
        "Ć†",
        "Ā°",
        "Ā±",
        "Ā²",
        "Ā³",
        "Ā´",
        "Āµ",
        "Ā¶",
        "Ā·",
        "Ćø",
        "Ā¹",
        "Å—",
        "Ā»",
        "Ā¼",
        "Ā½",
        "Ā¾",
        "Ć¦",
        "Ä„",
        "Ä®",
        "Ä€",
        "Ä†",
        "Ć„",
        "Ć…",
        "Ä’",
        "Ć‰",
        "Å¹",
        "Ä–",
        "Ä¢",
        "Ä¶",
        "ÄŖ",
        "Ä»",
        "Å\xa0",
        "Å…",
        "Ć“",
        "Ć•",
        "Ć–",
        "Ć—",
        "Å²",
        "ÅŖ",
        "Å»",
        "Å½",
        "Ä…",
        "ÄÆ",
        "Ä‡",
        "Ć¤",
        "Ä™",
        "Ä“",
        "Ä¨",
        "Ć©",
        "Åŗ",
        "Ä—",
        "Ä£",
        "Ä·",
        "Ä«",
        "Ä¼",
        "Å„",
        "Å†",
        "Ć³",
        "Å¨",
        "Ćµ",
        "Ć¶",
        "Ć·",
        "Å³",
        "Å‚",
        "Å›",
        "Å«",
        "Ć¼",
        "Å¼",
        "Å¾",
        "Ė™",
    ],
    "cp1258": [
        "â‚¬",
        "Æ’",
        "â€¦",
        "â€\xa0",
        "â€¡",
        "Ë†",
        "â€°",
        "â€¹",
        "Å’",
        "â€˜",
        "â€™",
        "â€œ",
        "â€¢",
        "â€“",
        "â€”",
        "Ëœ",
        "â„¢",
        "â€º",
        "Å“",
        "Å¸",
        "Â\xa0",
        "Â¡",
        "Â¢",
        "Â£",
        "Â¤",
        "Â¥",
        "Â¦",
        "Â§",
        "Â¨",
        "Â©",
        "Âª",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Â¯",
        "Â°",
        "Â±",
        "Â²",
        "Â³",
        "Â´",
        "Âµ",
        "Â¶",
        "Â·",
        "Â¸",
        "Â¹",
        "Âº",
        "Â»",
        "Â¼",
        "Â½",
        "Â¾",
        "Â¿",
        "Ă€",
        "Ă‚",
        "Ä‚",
        "Ă„",
        "Ă…",
        "Ă†",
        "Ă‡",
        "Ăˆ",
        "Ă‰",
        "Ă‹",
        "̀€",
        "Ă‘",
        "̀‰",
        "Ă“",
        "Ă”",
        "Æ\xa0",
        "Ă–",
        "Ă—",
        "Ă˜",
        "Ă™",
        "Ă›",
        "Ăœ",
        "Æ¯",
        "̀ƒ",
        "ĂŸ",
        "Ă\xa0",
        "Ă¡",
        "Ă¢",
        "Äƒ",
        "Ă¤",
        "Ă¥",
        "Ă¦",
        "Ă§",
        "Ă¨",
        "Ă©",
        "Ăª",
        "Ă«",
        "Ă\xad",
        "Ă®",
        "Ă¯",
        "Ä‘",
        "Ă±",
        "̀£",
        "Ă³",
        "Ă´",
        "Æ¡",
        "Ă¶",
        "Ă·",
        "Ă¸",
        "Ă¹",
        "Ăº",
        "Ă»",
        "Ă¼",
        "Æ°",
        "â‚«",
        "Ă¿",
    ],
    "latin_1": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Â¡",
        "Â¢",
        "Â£",
        "Â¤",
        "Â¥",
        "Â¦",
        "Â§",
        "Â¨",
        "Â©",
        "Âª",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Â¯",
        "Â°",
        "Â±",
        "Â²",
        "Â³",
        "Â´",
        "Âµ",
        "Â¶",
        "Â·",
        "Â¸",
        "Â¹",
        "Âº",
        "Â»",
        "Â¼",
        "Â½",
        "Â¾",
        "Â¿",
        "Ã\x80",
        "Ã\x81",
        "Ã\x82",
        "Ã\x83",
        "Ã\x84",
        "Ã\x85",
        "Ã\x86",
        "Ã\x87",
        "Ã\x88",
        "Ã\x89",
        "Ã\x8a",
        "Ã\x8b",
        "Ã\x8c",
        "Ã\x8d",
        "Ã\x8e",
        "Ã\x8f",
        "Ã\x90",
        "Ã\x91",
        "Ã\x92",
        "Ã\x93",
        "Ã\x94",
        "Ã\x95",
        "Ã\x96",
        "Ã\x97",
        "Ã\x98",
        "Ã\x99",
        "Ã\x9a",
        "Ã\x9b",
        "Ã\x9c",
        "Ã\x9d",
        "Ã\x9e",
        "Ã\x9f",
        "Ã\xa0",
        "Ã¡",
        "Ã¢",
        "Ã£",
        "Ã¤",
        "Ã¥",
        "Ã¦",
        "Ã§",
        "Ã¨",
        "Ã©",
        "Ãª",
        "Ã«",
        "Ã¬",
        "Ã\xad",
        "Ã®",
        "Ã¯",
        "Ã°",
        "Ã±",
        "Ã²",
        "Ã³",
        "Ã´",
        "Ãµ",
        "Ã¶",
        "Ã·",
        "Ã¸",
        "Ã¹",
        "Ãº",
        "Ã»",
        "Ã¼",
        "Ã½",
        "Ã¾",
        "Ã¿",
    ],
    "iso8859_2": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Ä\x84",
        "Ë\x98",
        "Ĺ\x81",
        "Â¤",
        "Ä˝",
        "Ĺ\x9a",
        "Â§",
        "Â¨",
        "Ĺ\xa0",
        "Ĺ\x9e",
        "Ĺ¤",
        "Ĺš",
        "Â\xad",
        "Ĺ˝",
        "Ĺť",
        "Â°",
        "Ä\x85",
        "Ë\x9b",
        "Ĺ\x82",
        "Â´",
        "Äž",
        "Ĺ\x9b",
        "Ë\x87",
        "Â¸",
        "ĹĄ",
        "Ĺ\x9f",
        "ĹĽ",
        "Ĺş",
        "Ë\x9d",
        "Ĺž",
        "Ĺź",
        "Ĺ\x94",
        "Ă\x81",
        "Ă\x82",
        "Ä\x82",
        "Ă\x84",
        "Äš",
        "Ä\x86",
        "Ă\x87",
        "Ä\x8c",
        "Ă\x89",
        "Ä\x98",
        "Ă\x8b",
        "Ä\x9a",
        "Ă\x8d",
        "Ă\x8e",
        "Ä\x8e",
        "Ä\x90",
        "Ĺ\x83",
        "Ĺ\x87",
        "Ă\x93",
        "Ă\x94",
        "Ĺ\x90",
        "Ă\x96",
        "Ă\x97",
        "Ĺ\x98",
        "ĹŽ",
        "Ă\x9a",
        "Ĺ°",
        "Ă\x9c",
        "Ă\x9d",
        "Ĺ˘",
        "Ă\x9f",
        "Ĺ\x95",
        "ĂĄ",
        "Ă˘",
        "Ä\x83",
        "Ă¤",
        "Äş",
        "Ä\x87",
        "Ă§",
        "Ä\x8d",
        "ĂŠ",
        "Ä\x99",
        "ĂŤ",
        "Ä\x9b",
        "Ă\xad",
        "ĂŽ",
        "Ä\x8f",
        "Ä\x91",
        "Ĺ\x84",
        "Ĺ\x88",
        "Ăł",
        "Ă´",
        "Ĺ\x91",
        "Ăś",
        "Ăˇ",
        "Ĺ\x99",
        "ĹŻ",
        "Ăş",
        "Ĺą",
        "Ăź",
        "Ă˝",
        "ĹŁ",
        "Ë\x99",
    ],
    "iso8859_3": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "ÄĤ",
        "Ë\x98",
        "Â£",
        "Â¤",
        "Ä¤",
        "Â§",
        "Â¨",
        "Ä°",
        "Ċ\x9e",
        "Ä\x9e",
        "Ä´",
        "Â\xad",
        "Ċğ",
        "Â°",
        "Ä§",
        "Â²",
        "Â³",
        "Â´",
        "Âµ",
        "Â·",
        "Â¸",
        "Äħ",
        "Ċ\x9f",
        "Ä\x9f",
        "Äµ",
        "Â½",
        "Ċĵ",
        "Ä\x8a",
        "Ä\x88",
        "Ä\xa0",
        "Ä\x9c",
        "ĊĴ",
        "Ċ\x9c",
        "Ä\x8b",
        "Ä\x89",
        "ÄĦ",
        "Ä\x9d",
        "Ċ\xad",
        "Ċ\x9d",
        "Ë\x99",
    ],
    "iso8859_4": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Ä\x84",
        "Ä¸",
        "Å\x96",
        "Â¤",
        "Ä¨",
        "Äģ",
        "Â§",
        "Â¨",
        "Å\xa0",
        "Ä\x92",
        "Äĸ",
        "ÅĻ",
        "Â\xad",
        "ÅŊ",
        "Â¯",
        "Â°",
        "Ä\x85",
        "Ë\x9b",
        "Å\x97",
        "Â´",
        "ÄŠ",
        "Äŧ",
        "Ë\x87",
        "Â¸",
        "ÅĄ",
        "Ä\x93",
        "ÄŖ",
        "Å§",
        "Å\x8a",
        "Åž",
        "Å\x8b",
        "Ä\x80",
        "Ã\x81",
        "Ã\x82",
        "Ã\x83",
        "Ã\x84",
        "Ã\x85",
        "Ã\x86",
        "ÄŽ",
        "Ä\x8c",
        "Ã\x89",
        "Ä\x98",
        "Ã\x8b",
        "Ä\x96",
        "Ã\x8d",
        "Ã\x8e",
        "ÄĒ",
        "Ä\x90",
        "Å\x85",
        "Å\x8c",
        "Äļ",
        "Ã\x94",
        "Ã\x95",
        "Ã\x96",
        "Ã\x97",
        "Ã\x98",
        "Å˛",
        "Ã\x9a",
        "Ã\x9b",
        "Ã\x9c",
        "Å¨",
        "ÅĒ",
        "Ã\x9f",
        "Ä\x81",
        "ÃĄ",
        "Ãĸ",
        "ÃŖ",
        "Ã¤",
        "ÃĨ",
        "ÃĻ",
        "Ä¯",
        "Ä\x8d",
        "ÃŠ",
        "Ä\x99",
        "ÃĢ",
        "Ä\x97",
        "Ã\xad",
        "ÃŽ",
        "ÄĢ",
        "Ä\x91",
        "Å\x86",
        "Å\x8d",
        "Äˇ",
        "Ã´",
        "Ãĩ",
        "Ãļ",
        "Ãˇ",
        "Ã¸",
        "Åŗ",
        "Ãē",
        "Ãģ",
        "Ãŧ",
        "ÅŠ",
        "ÅĢ",
        "Ë\x99",
    ],
    "iso8859_5": [
        "Т\x80",
        "Т\x81",
        "Т\x82",
        "Т\x83",
        "Т\x84",
        "Т\x85",
        "Т\x86",
        "Т\x87",
        "Т\x88",
        "Т\x89",
        "Т\x8a",
        "Т\x8b",
        "Т\x8c",
        "Т\x8d",
        "Т\x8e",
        "Т\x8f",
        "Т\x90",
        "Т\x91",
        "Т\x92",
        "Т\x93",
        "Т\x94",
        "Т\x95",
        "Т\x96",
        "Т\x97",
        "Т\x98",
        "Т\x99",
        "Т\x9a",
        "Т\x9b",
        "Т\x9c",
        "Т\x9d",
        "Т\x9e",
        "Т\x9f",
        "Т\xa0",
        "а\x81",
        "а\x82",
        "а\x83",
        "а\x84",
        "а\x85",
        "а\x86",
        "а\x87",
        "а\x88",
        "а\x89",
        "а\x8a",
        "а\x8b",
        "а\x8c",
        "Т\xad",
        "а\x8e",
        "а\x8f",
        "а\x90",
        "а\x91",
        "а\x92",
        "а\x93",
        "а\x94",
        "а\x95",
        "а\x96",
        "а\x97",
        "а\x98",
        "а\x99",
        "а\x9a",
        "а\x9b",
        "а\x9c",
        "а\x9d",
        "а\x9e",
        "а\x9f",
        "а\xa0",
        "аЁ",
        "аЂ",
        "аЃ",
        "аЄ",
        "аЅ",
        "аІ",
        "аЇ",
        "аЈ",
        "аЉ",
        "аЊ",
        "аЋ",
        "аЌ",
        "а\xad",
        "аЎ",
        "аЏ",
        "аА",
        "аБ",
        "аВ",
        "аГ",
        "аД",
        "аЕ",
        "аЖ",
        "аЗ",
        "аИ",
        "аЙ",
        "аК",
        "аЛ",
        "аМ",
        "аН",
        "аО",
        "аП",
        "б\x80",
        "б\x81",
        "б\x82",
        "б\x83",
        "б\x84",
        "б\x85",
        "б\x86",
        "б\x87",
        "б\x88",
        "б\x89",
        "б\x8a",
        "б\x8b",
        "б\x8c",
        "б\x8d",
        "б\x8e",
        "б\x8f",
        "т\x84\x96",
        "б\x91",
        "б\x92",
        "б\x93",
        "б\x94",
        "б\x95",
        "б\x96",
        "б\x97",
        "б\x98",
        "б\x99",
        "б\x9a",
        "б\x9b",
        "б\x9c",
        "ТЇ",
        "б\x9e",
        "б\x9f",
    ],
    "iso8859_6": [
        "آ\x80",
        "آ\x81",
        "آ\x82",
        "آ\x83",
        "آ\x84",
        "آ\x85",
        "آ\x86",
        "آ\x87",
        "آ\x88",
        "آ\x89",
        "آ\x8a",
        "آ\x8b",
        "آ\x8c",
        "آ\x8d",
        "آ\x8e",
        "آ\x8f",
        "آ\x90",
        "آ\x91",
        "آ\x92",
        "آ\x93",
        "آ\x94",
        "آ\x95",
        "آ\x96",
        "آ\x97",
        "آ\x98",
        "آ\x99",
        "آ\x9a",
        "آ\x9b",
        "آ\x9c",
        "آ\x9d",
        "آ\x9e",
        "آ\x9f",
        "آ\xa0",
        "آ¤",
        "ظ\x8c",
        "آ\xad",
        "ظ\x9b",
        "ظ\x9f",
        "ظ¤",
        "ظ،",
        "ظ\xad",
        "ع\x80",
        "ع\x81",
        "ع\x82",
        "ع\x83",
        "ع\x84",
        "ع\x85",
        "ع\x86",
        "ع\x87",
        "ع\x88",
        "ع\x89",
        "ع\x8a",
        "ع\x8b",
        "ع\x8c",
        "ع\x8d",
        "ع\x8e",
        "ع\x8f",
        "ع\x90",
        "ع\x91",
        "ع\x92",
    ],
    "iso8859_7": [
        "Β\x80",
        "Β\x81",
        "Β\x82",
        "Β\x83",
        "Β\x84",
        "Β\x85",
        "Β\x86",
        "Β\x87",
        "Β\x88",
        "Β\x89",
        "Β\x8a",
        "Β\x8b",
        "Β\x8c",
        "Β\x8d",
        "Β\x8e",
        "Β\x8f",
        "Β\x90",
        "Β\x91",
        "Β\x92",
        "Β\x93",
        "Β\x94",
        "Β\x95",
        "Β\x96",
        "Β\x97",
        "Β\x98",
        "Β\x99",
        "Β\x9a",
        "Β\x9b",
        "Β\x9c",
        "Β\x9d",
        "Β\x9e",
        "Β\x9f",
        "Β\xa0",
        "β\x80\x98",
        "β\x80\x99",
        "Β£",
        "β\x82¬",
        "β\x82―",
        "Β¦",
        "Β§",
        "Β¨",
        "Β©",
        "ΝΊ",
        "Β«",
        "Β¬",
        "Β\xad",
        "β\x80\x95",
        "Β°",
        "Β±",
        "Β²",
        "Β³",
        "Ξ\x84",
        "Ξ\x85",
        "Ξ\x86",
        "Β·",
        "Ξ\x88",
        "Ξ\x89",
        "Ξ\x8a",
        "Β»",
        "Ξ\x8c",
        "Β½",
        "Ξ\x8e",
        "Ξ\x8f",
        "Ξ\x90",
        "Ξ\x91",
        "Ξ\x92",
        "Ξ\x93",
        "Ξ\x94",
        "Ξ\x95",
        "Ξ\x96",
        "Ξ\x97",
        "Ξ\x98",
        "Ξ\x99",
        "Ξ\x9a",
        "Ξ\x9b",
        "Ξ\x9c",
        "Ξ\x9d",
        "Ξ\x9e",
        "Ξ\x9f",
        "Ξ\xa0",
        "Ξ‘",
        "Ξ£",
        "Ξ€",
        "Ξ₯",
        "Ξ¦",
        "Ξ§",
        "Ξ¨",
        "Ξ©",
        "Ξͺ",
        "Ξ«",
        "Ξ¬",
        "Ξ\xad",
        "Ξ―",
        "Ξ°",
        "Ξ±",
        "Ξ²",
        "Ξ³",
        "Ξ΄",
        "Ξ΅",
        "ΞΆ",
        "Ξ·",
        "ΞΈ",
        "ΞΉ",
        "ΞΊ",
        "Ξ»",
        "ΞΌ",
        "Ξ½",
        "ΞΎ",
        "ΞΏ",
        "Ο\x80",
        "Ο\x81",
        "Ο\x82",
        "Ο\x83",
        "Ο\x84",
        "Ο\x85",
        "Ο\x86",
        "Ο\x87",
        "Ο\x88",
        "Ο\x89",
        "Ο\x8a",
        "Ο\x8b",
        "Ο\x8c",
        "Ο\x8d",
        "Ο\x8e",
    ],
    "iso8859_8": ["ג\x80\x97", "ג\x80\x8e", "ג\x80\x8f"],
    "iso8859_9": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Â¡",
        "Â¢",
        "Â£",
        "Â¤",
        "Â¥",
        "Â¦",
        "Â§",
        "Â¨",
        "Â©",
        "Âª",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Â¯",
        "Â°",
        "Â±",
        "Â²",
        "Â³",
        "Â´",
        "Âµ",
        "Â¶",
        "Â·",
        "Â¸",
        "Â¹",
        "Âº",
        "Â»",
        "Â¼",
        "Â½",
        "Â¾",
        "Â¿",
        "Ã\x80",
        "Ã\x81",
        "Ã\x82",
        "Ã\x83",
        "Ã\x84",
        "Ã\x85",
        "Ã\x86",
        "Ã\x87",
        "Ã\x88",
        "Ã\x89",
        "Ã\x8a",
        "Ã\x8b",
        "Ã\x8c",
        "Ã\x8d",
        "Ã\x8e",
        "Ã\x8f",
        "Ä\x9e",
        "Ã\x91",
        "Ã\x92",
        "Ã\x93",
        "Ã\x94",
        "Ã\x95",
        "Ã\x96",
        "Ã\x97",
        "Ã\x98",
        "Ã\x99",
        "Ã\x9a",
        "Ã\x9b",
        "Ã\x9c",
        "Ä°",
        "Å\x9e",
        "Ã\x9f",
        "Ã\xa0",
        "Ã¡",
        "Ã¢",
        "Ã£",
        "Ã¤",
        "Ã¥",
        "Ã¦",
        "Ã§",
        "Ã¨",
        "Ã©",
        "Ãª",
        "Ã«",
        "Ã¬",
        "Ã\xad",
        "Ã®",
        "Ã¯",
        "Ä\x9f",
        "Ã±",
        "Ã²",
        "Ã³",
        "Ã´",
        "Ãµ",
        "Ã¶",
        "Ã·",
        "Ã¸",
        "Ã¹",
        "Ãº",
        "Ã»",
        "Ã¼",
        "Ä±",
        "Å\x9f",
        "Ã¿",
    ],
    "iso8859_10": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Ä\x84",
        "Ä\x92",
        "ÄĒ",
        "ÄŠ",
        "ÄĻ",
        "Äķ",
        "Â§",
        "Äŧ",
        "Ä\x90",
        "Å\xa0",
        "ÅĶ",
        "Å―",
        "Â\xad",
        "ÅŠ",
        "Å\x8a",
        "Â°",
        "Ä\x85",
        "Ä\x93",
        "ÄĢ",
        "ÄŦ",
        "ÄĐ",
        "Ä·",
        "Â·",
        "Äž",
        "Ä\x91",
        "ÅĄ",
        "Å§",
        "Åū",
        "â\x80\x95",
        "ÅŦ",
        "Å\x8b",
        "Ä\x80",
        "Ã\x81",
        "Ã\x82",
        "Ã\x83",
        "Ã\x84",
        "Ã\x85",
        "Ã\x86",
        "ÄŪ",
        "Ä\x8c",
        "Ã\x89",
        "Ä\x98",
        "Ã\x8b",
        "Ä\x96",
        "Ã\x8d",
        "Ã\x8e",
        "Ã\x8f",
        "Ã\x90",
        "Å\x85",
        "Å\x8c",
        "Ã\x93",
        "Ã\x94",
        "Ã\x95",
        "Ã\x96",
        "ÅĻ",
        "Ã\x98",
        "Åē",
        "Ã\x9a",
        "Ã\x9b",
        "Ã\x9c",
        "Ã\x9d",
        "Ã\x9e",
        "Ã\x9f",
        "Ä\x81",
        "ÃĄ",
        "ÃĒ",
        "ÃĢ",
        "ÃĪ",
        "ÃĨ",
        "ÃĶ",
        "ÄŊ",
        "Ä\x8d",
        "ÃĐ",
        "Ä\x99",
        "ÃŦ",
        "Ä\x97",
        "Ã\xad",
        "ÃŪ",
        "ÃŊ",
        "Ã°",
        "Å\x86",
        "Å\x8d",
        "Ãģ",
        "Ãī",
        "Ãĩ",
        "Ãķ",
        "ÅĐ",
        "Ãļ",
        "Åģ",
        "Ãš",
        "Ãŧ",
        "Ãž",
        "Ã―",
        "Ãū",
        "Äļ",
    ],
    "iso8859_11": [
        "ย\x80",
        "ย\x81",
        "ย\x82",
        "ย\x83",
        "ย\x84",
        "ย\x85",
        "ย\x86",
        "ย\x87",
        "ย\x88",
        "ย\x89",
        "ย\x8a",
        "ย\x8b",
        "ย\x8c",
        "ย\x8d",
        "ย\x8e",
        "ย\x8f",
        "ย\x90",
        "ย\x91",
        "ย\x92",
        "ย\x93",
        "ย\x94",
        "ย\x95",
        "ย\x96",
        "ย\x97",
        "ย\x98",
        "ย\x99",
        "ย\x9a",
        "ย\x9b",
        "ย\x9c",
        "ย\x9d",
        "ย\x9e",
        "ย\x9f",
        "ย\xa0",
        "เธ\x81",
        "เธ\x82",
        "เธ\x83",
        "เธ\x84",
        "เธ\x85",
        "เธ\x86",
        "เธ\x87",
        "เธ\x88",
        "เธ\x89",
        "เธ\x8a",
        "เธ\x8b",
        "เธ\x8c",
        "เธ\x8d",
        "เธ\x8e",
        "เธ\x8f",
        "เธ\x90",
        "เธ\x91",
        "เธ\x92",
        "เธ\x93",
        "เธ\x94",
        "เธ\x95",
        "เธ\x96",
        "เธ\x97",
        "เธ\x98",
        "เธ\x99",
        "เธ\x9a",
        "เธ\x9b",
        "เธ\x9c",
        "เธ\x9d",
        "เธ\x9e",
        "เธ\x9f",
        "เธ\xa0",
        "เธก",
        "เธข",
        "เธฃ",
        "เธค",
        "เธฅ",
        "เธฆ",
        "เธง",
        "เธจ",
        "เธฉ",
        "เธช",
        "เธซ",
        "เธฌ",
        "เธญ",
        "เธฎ",
        "เธฏ",
        "เธฐ",
        "เธฑ",
        "เธฒ",
        "เธณ",
        "เธด",
        "เธต",
        "เธถ",
        "เธท",
        "เธธ",
        "เธน",
        "เธบ",
        "เธฟ",
        "เน\x80",
        "เน\x81",
        "เน\x82",
        "เน\x83",
        "เน\x84",
        "เน\x85",
        "เน\x86",
        "เน\x87",
        "เน\x88",
        "เน\x89",
        "เน\x8a",
        "เน\x8b",
        "เน\x8c",
        "เน\x8d",
        "เน\x8e",
        "เน\x8f",
        "เน\x90",
        "เน\x91",
        "เน\x92",
        "เน\x93",
        "เน\x94",
        "เน\x95",
        "เน\x96",
        "เน\x97",
        "เน\x98",
        "เน\x99",
        "เน\x9a",
        "เน\x9b",
    ],
    "iso8859_13": [
        "Ā\x80",
        "Ā\x81",
        "Ā\x82",
        "Ā\x83",
        "Ā\x84",
        "Ā\x85",
        "Ā\x86",
        "Ā\x87",
        "Ā\x88",
        "Ā\x89",
        "Ā\x8a",
        "Ā\x8b",
        "Ā\x8c",
        "Ā\x8d",
        "Ā\x8e",
        "Ā\x8f",
        "Ā\x90",
        "Ā\x91",
        "Ā\x92",
        "Ā\x93",
        "Ā\x94",
        "Ā\x95",
        "Ā\x96",
        "Ā\x97",
        "Ā\x98",
        "Ā\x99",
        "Ā\x9a",
        "Ā\x9b",
        "Ā\x9c",
        "Ā\x9d",
        "Ā\x9e",
        "Ā\x9f",
        "Ā\xa0",
        "ā\x80\x9d",
        "Ā¢",
        "Ā£",
        "Ā¤",
        "ā\x80\x9e",
        "Ā¦",
        "Ā§",
        "Ć\x98",
        "Ā©",
        "Å\x96",
        "Ā«",
        "Ā¬",
        "Ā\xad",
        "Ā®",
        "Ć\x86",
        "Ā°",
        "Ā±",
        "Ā²",
        "Ā³",
        "ā\x80\x9c",
        "Āµ",
        "Ā¶",
        "Ā·",
        "Ćø",
        "Ā¹",
        "Å\x97",
        "Ā»",
        "Ā¼",
        "Ā½",
        "Ā¾",
        "Ć¦",
        "Ä\x84",
        "Ä®",
        "Ä\x80",
        "Ä\x86",
        "Ć\x84",
        "Ć\x85",
        "Ä\x98",
        "Ä\x92",
        "Ä\x8c",
        "Ć\x89",
        "Å¹",
        "Ä\x96",
        "Ä¢",
        "Ä¶",
        "ÄŖ",
        "Ä»",
        "Å\xa0",
        "Å\x83",
        "Å\x85",
        "Ć\x93",
        "Å\x8c",
        "Ć\x95",
        "Ć\x96",
        "Ć\x97",
        "Å²",
        "Å\x81",
        "Å\x9a",
        "ÅŖ",
        "Ć\x9c",
        "Å»",
        "Å½",
        "Ć\x9f",
        "Ä\x85",
        "ÄÆ",
        "Ä\x81",
        "Ä\x87",
        "Ć¤",
        "Ć„",
        "Ä\x99",
        "Ä\x93",
        "Ä\x8d",
        "Ć©",
        "Åŗ",
        "Ä\x97",
        "Ä£",
        "Ä·",
        "Ä«",
        "Ä¼",
        "Å”",
        "Å\x84",
        "Å\x86",
        "Ć³",
        "Å\x8d",
        "Ćµ",
        "Ć¶",
        "Ć·",
        "Å³",
        "Å\x82",
        "Å\x9b",
        "Å«",
        "Ć¼",
        "Å¼",
        "Å¾",
        "ā\x80\x99",
    ],
    "iso8859_14": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "áẁ\x82",
        "áẁ\x83",
        "Â£",
        "Ä\x8a",
        "Ä\x8b",
        "áẁ\x8a",
        "Â§",
        "áẃ\x80",
        "Â©",
        "áẃ\x82",
        "áẁ\x8b",
        "áṠĠ",
        "Â\xad",
        "Â®",
        "Åẁ",
        "áẁ\x9e",
        "áẁ\x9f",
        "Ä\xa0",
        "ÄḂ",
        "áṗ\x80",
        "áṗ\x81",
        "Â¶",
        "áṗ\x96",
        "áẃ\x81",
        "áṗ\x97",
        "áẃ\x83",
        "áṗ\xa0",
        "áṠġ",
        "áẃ\x84",
        "áẃ\x85",
        "áṗḂ",
        "Ã\x80",
        "Ã\x81",
        "Ã\x82",
        "Ã\x83",
        "Ã\x84",
        "Ã\x85",
        "Ã\x86",
        "Ã\x87",
        "Ã\x88",
        "Ã\x89",
        "Ã\x8a",
        "Ã\x8b",
        "Ã\x8c",
        "Ã\x8d",
        "Ã\x8e",
        "Ã\x8f",
        "ÅṀ",
        "Ã\x91",
        "Ã\x92",
        "Ã\x93",
        "Ã\x94",
        "Ã\x95",
        "Ã\x96",
        "áṗẂ",
        "Ã\x98",
        "Ã\x99",
        "Ã\x9a",
        "Ã\x9b",
        "Ã\x9c",
        "Ã\x9d",
        "Å¶",
        "Ã\x9f",
        "Ã\xa0",
        "ÃḂ",
        "Ãḃ",
        "Ã£",
        "ÃĊ",
        "Ãċ",
        "ÃḊ",
        "Ã§",
        "ÃẀ",
        "Ã©",
        "ÃẂ",
        "Ãḋ",
        "ÃỲ",
        "Ã\xad",
        "Ã®",
        "ÃŸ",
        "Åṁ",
        "Ãḟ",
        "ÃĠ",
        "Ãġ",
        "ÃṀ",
        "Ãṁ",
        "Ã¶",
        "áṗḋ",
        "Ãẁ",
        "Ãṗ",
        "Ãẃ",
        "ÃṠ",
        "Ãỳ",
        "ÃẄ",
        "ÅṖ",
        "Ãṡ",
    ],
    "iso8859_15": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Â¡",
        "Â¢",
        "Â£",
        "â\x82¬",
        "Â¥",
        "Å\xa0",
        "Â§",
        "Å¡",
        "Â©",
        "Âª",
        "Â«",
        "Â¬",
        "Â\xad",
        "Â®",
        "Â¯",
        "Â°",
        "Â±",
        "Â²",
        "Â³",
        "Åœ",
        "Âµ",
        "Â¶",
        "Â·",
        "ÅŸ",
        "Â¹",
        "Âº",
        "Â»",
        "Å\x92",
        "Å\x93",
        "Åž",
        "Â¿",
        "Ã\x80",
        "Ã\x81",
        "Ã\x82",
        "Ã\x83",
        "Ã\x84",
        "Ã\x85",
        "Ã\x86",
        "Ã\x87",
        "Ã\x88",
        "Ã\x89",
        "Ã\x8a",
        "Ã\x8b",
        "Ã\x8c",
        "Ã\x8d",
        "Ã\x8e",
        "Ã\x8f",
        "Ã\x90",
        "Ã\x91",
        "Ã\x92",
        "Ã\x93",
        "Ã\x94",
        "Ã\x95",
        "Ã\x96",
        "Ã\x97",
        "Ã\x98",
        "Ã\x99",
        "Ã\x9a",
        "Ã\x9b",
        "Ã\x9c",
        "Ã\x9d",
        "Ã\x9e",
        "Ã\x9f",
        "Ã\xa0",
        "Ã¡",
        "Ã¢",
        "Ã£",
        "Ã€",
        "Ã¥",
        "ÃŠ",
        "Ã§",
        "Ãš",
        "Ã©",
        "Ãª",
        "Ã«",
        "Ã¬",
        "Ã\xad",
        "Ã®",
        "Ã¯",
        "Ã°",
        "Ã±",
        "Ã²",
        "Ã³",
        "ÃŽ",
        "Ãµ",
        "Ã¶",
        "Ã·",
        "Ãž",
        "Ã¹",
        "Ãº",
        "Ã»",
        "ÃŒ",
        "Ãœ",
        "ÃŸ",
        "Ã¿",
    ],
    "iso8859_16": [
        "Â\x80",
        "Â\x81",
        "Â\x82",
        "Â\x83",
        "Â\x84",
        "Â\x85",
        "Â\x86",
        "Â\x87",
        "Â\x88",
        "Â\x89",
        "Â\x8a",
        "Â\x8b",
        "Â\x8c",
        "Â\x8d",
        "Â\x8e",
        "Â\x8f",
        "Â\x90",
        "Â\x91",
        "Â\x92",
        "Â\x93",
        "Â\x94",
        "Â\x95",
        "Â\x96",
        "Â\x97",
        "Â\x98",
        "Â\x99",
        "Â\x9a",
        "Â\x9b",
        "Â\x9c",
        "Â\x9d",
        "Â\x9e",
        "Â\x9f",
        "Â\xa0",
        "Ä\x84",
        "Ä\x85",
        "Ć\x81",
        "â\x82Ź",
        "â\x80\x9e",
        "Ć\xa0",
        "Â§",
        "ĆĄ",
        "Â©",
        "È\x98",
        "Â«",
        "Ćč",
        "Â\xad",
        "Ćș",
        "Ć»",
        "Â°",
        "Â±",
        "Ä\x8c",
        "Ć\x82",
        "Ćœ",
        "â\x80\x9d",
        "Â¶",
        "Â·",
        "ĆŸ",
        "Ä\x8d",
        "È\x99",
        "Â»",
        "Ć\x92",
        "Ć\x93",
        "Ćž",
        "ĆŒ",
        "Ă\x80",
        "Ă\x81",
        "Ă\x82",
        "Ä\x82",
        "Ă\x84",
        "Ä\x86",
        "Ă\x86",
        "Ă\x87",
        "Ă\x88",
        "Ă\x89",
        "Ă\x8a",
        "Ă\x8b",
        "Ă\x8c",
        "Ă\x8d",
        "Ă\x8e",
        "Ă\x8f",
        "Ä\x90",
        "Ć\x83",
        "Ă\x92",
        "Ă\x93",
        "Ă\x94",
        "Ć\x90",
        "Ă\x96",
        "Ć\x9a",
        "Ć°",
        "Ă\x99",
        "Ă\x9a",
        "Ă\x9b",
        "Ă\x9c",
        "Ä\x98",
        "È\x9a",
        "Ă\x9f",
        "Ă\xa0",
        "ĂĄ",
        "Ăą",
        "Ä\x83",
        "Ă€",
        "Ä\x87",
        "ĂŠ",
        "Ă§",
        "Ăš",
        "Ă©",
        "ĂȘ",
        "Ă«",
        "ĂŹ",
        "Ă\xad",
        "Ăź",
        "ĂŻ",
        "Ä\x91",
        "Ć\x84",
        "ĂČ",
        "Ăł",
        "ĂŽ",
        "Ć\x91",
        "Ă¶",
        "Ć\x9b",
        "Ć±",
        "Ăč",
        "Ăș",
        "Ă»",
        "ĂŒ",
        "Ä\x99",
        "È\x9b",
        "Ăż",
    ],
    "koi8_r": [
        "Б■─",
        "Б■┌",
        "Б■▄",
        "Б■░",
        "Б■■",
        "Б■≤",
        "Б■°",
        "Б■╓",
        "Б■╛",
        "Б■╢",
        "Б■╪",
        "Б√─",
        "Б√└",
        "Б√┬",
        "Б√▄",
        "Б√░",
        "Б√▒",
        "Б√▓",
        "Б√⌠",
        "Б▄═",
        "Б√═",
        "Б┬≥",
        "Б┬\xa0",
        "Б┴┬",
        "Б┴╓",
        "Б┴╔",
        "б═",
        "Б▄║",
        "б╟",
        "б╡",
        "б╥",
        "ц╥",
        "Б∙░",
        "Б∙▒",
        "Б∙▓",
        "я▒",
        "Б∙⌠",
        "Б∙■",
        "Б∙∙",
        "Б∙√",
        "Б∙≈",
        "Б∙≤",
        "Б∙≥",
        "Б∙\xa0",
        "Б∙⌡",
        "Б∙°",
        "Б∙²",
        "Б∙·",
        "Б∙÷",
        "Б∙═",
        "Б∙║",
        "п│",
        "Б∙╒",
        "Б∙ё",
        "Б∙╓",
        "Б∙╔",
        "Б∙╕",
        "Б∙╖",
        "Б∙╗",
        "Б∙╘",
        "Б∙╙",
        "Б∙╚",
        "Б∙╛",
        "б╘",
        "я▌",
        "п╟",
        "п╠",
        "я├",
        "п╢",
        "п╣",
        "я└",
        "пЁ",
        "я┘",
        "п╦",
        "п╧",
        "п╨",
        "п╩",
        "п╪",
        "п╫",
        "п╬",
        "п©",
        "я▐",
        "я─",
        "я│",
        "я┌",
        "я┐",
        "п╤",
        "п╡",
        "я▄",
        "я▀",
        "п╥",
        "я┬",
        "я█",
        "я┴",
        "я┤",
        "я┼",
        "п╝",
        "п░",
        "п▒",
        "п╕",
        "п■",
        "п∙",
        "п╓",
        "п⌠",
        "п╔",
        "п≤",
        "п≥",
        "п\xa0",
        "п⌡",
        "п°",
        "п²",
        "п·",
        "п÷",
        "п╞",
        "п═",
        "п║",
        "п╒",
        "пё",
        "п√",
        "п▓",
        "п╛",
        "п╚",
        "п≈",
        "п╗",
        "п╜",
        "п╘",
        "п╖",
        "п╙",
    ],
    "koi8_t": [
        "р›",
        "р“",
        "р’",
        "Бқ¦",
        "Бқӯ",
        "Бқ°",
        "рЁ",
        "Бқ№",
        "р²",
        "р·",
        "р¶",
        "Бқ™",
        "БқӮ",
        "Бқ“",
        "Бқ”",
        "Б„Ӯ",
        "с®",
        "я‘",
        "б¤",
        "сё",
        "б¦",
        "б§",
        "б«",
        "б¬",
        "б\xad",
        "б®",
        "б°",
        "б±",
        "б²",
        "пғ",
        "сӮ",
        "б¶",
        "б·",
        "Б„–",
        "б»",
        "яҶ",
        "п°",
        "п±",
        "я†",
        "пӢ",
        "я„",
        "пЁ",
        "я…",
        "п№",
        "п»",
        "п©",
        "яқ",
        "яғ",
        "я‚",
        "яҒ",
        "п¶",
        "п²",
        "яҲ",
        "я‹",
        "п·",
        "яҷ",
        "я‰",
        "я‡",
        "яҳ",
        "п®",
        "пҚ",
        "п‘",
        "п¦",
        "п”",
        "п•",
        "п¤",
        "п“",
        "пӣ",
        "п™",
        "п›",
        "пӯ",
        "пӮ",
        "пё",
        "п–",
        "п’",
        "п¬",
        "п«",
        "п—",
        "п\xad",
        "п§",
    ],
    "koi8_u": [
        "Б■─",
        "Б■┌",
        "Б■▄",
        "Б■░",
        "Б■■",
        "Б■≤",
        "Б■°",
        "Б■є",
        "Б■╛",
        "Б■Є",
        "Б■╪",
        "Б√─",
        "Б√└",
        "Б√┬",
        "Б√▄",
        "Б√░",
        "Б√▒",
        "Б√▓",
        "Б√⌠",
        "Б▄═",
        "Б√═",
        "Б┬≥",
        "Б┬\xa0",
        "Б┴┬",
        "Б┴є",
        "Б┴╔",
        "б═",
        "Б▄║",
        "б╟",
        "б╡",
        "бЇ",
        "цЇ",
        "Б∙░",
        "Б∙▒",
        "Б∙▓",
        "я▒",
        "я■",
        "Б∙■",
        "я√",
        "я≈",
        "Б∙≈",
        "Б∙≤",
        "Б∙≥",
        "Б∙\xa0",
        "Б∙⌡",
        "р▒",
        "Б∙²",
        "Б∙·",
        "Б∙÷",
        "Б∙═",
        "Б∙║",
        "п│",
        "п└",
        "Б∙ё",
        "п├",
        "п┤",
        "Б∙і",
        "Б∙ї",
        "Б∙╗",
        "Б∙╘",
        "Б∙╙",
        "р░",
        "Б∙╛",
        "б╘",
        "я▌",
        "п╟",
        "п╠",
        "я├",
        "пЄ",
        "п╣",
        "я└",
        "пЁ",
        "я┘",
        "п╦",
        "п╧",
        "п╨",
        "п╩",
        "п╪",
        "пҐ",
        "п╬",
        "п©",
        "я▐",
        "я─",
        "я│",
        "я┌",
        "я┐",
        "пІ",
        "п╡",
        "я▄",
        "я▀",
        "пЇ",
        "я┬",
        "я█",
        "я┴",
        "я┤",
        "я┼",
        "п╝",
        "п░",
        "п▒",
        "пі",
        "п■",
        "п∙",
        "пє",
        "п⌠",
        "п╔",
        "п≤",
        "п≥",
        "п\xa0",
        "п⌡",
        "п°",
        "п²",
        "п·",
        "п÷",
        "п╞",
        "п═",
        "п║",
        "п╒",
        "пё",
        "п√",
        "п▓",
        "п╛",
        "п╚",
        "п≈",
        "п╗",
        "пґ",
        "п╘",
        "пї",
        "п╙",
    ],
    "kz1048": [
        "Р‚",
        "Рѓ",
        "вЂљ",
        "С“",
        "вЂһ",
        "вЂ¦",
        "вЂ\xa0",
        "вЂҰ",
        "в‚¬",
        "вЂ°",
        "Р‰",
        "вЂ№",
        "РЉ",
        "Тљ",
        "Тғ",
        "РЏ",
        "С’",
        "вЂ™",
        "вЂњ",
        "вЂқ",
        "вЂұ",
        "вЂ“",
        "вЂ”",
        "в„ұ",
        "С™",
        "вЂғ",
        "Сљ",
        "Т›",
        "Т»",
        "Сџ",
        "В\xa0",
        "Т°",
        "Т±",
        "В¤",
        "УЁ",
        "В¦",
        "В§",
        "РЃ",
        "В©",
        "Т’",
        "В«",
        "В¬",
        "В\xad",
        "В®",
        "Т®",
        "В°",
        "В±",
        "Р†",
        "С–",
        "У©",
        "Вµ",
        "В¶",
        "В·",
        "С‘",
        "в„–",
        "Т“",
        "В»",
        "У™",
        "Тұ",
        "ТӘ",
        "ТҮ",
        "Рђ",
        "Р‘",
        "Р’",
        "Р“",
        "Р”",
        "Р•",
        "Р–",
        "Р—",
        "Р™",
        "Рљ",
        "Р›",
        "Рњ",
        "Рқ",
        "Рһ",
        "Рџ",
        "Р\xa0",
        "РҰ",
        "Рұ",
        "РӘ",
        "Р¤",
        "РӨ",
        "Р¦",
        "Р§",
        "РЁ",
        "Р©",
        "РҒ",
        "Р«",
        "Р¬",
        "Р\xad",
        "Р®",
        "РҮ",
        "Р°",
        "Р±",
        "РІ",
        "Рі",
        "Рө",
        "Рµ",
        "Р¶",
        "Р·",
        "Рё",
        "Р№",
        "Рғ",
        "Р»",
        "Рә",
        "РҢ",
        "Рң",
        "Рү",
        "СЂ",
        "СЃ",
        "С‚",
        "Сѓ",
        "С„",
        "С…",
        "С†",
        "С‡",
        "С€",
        "С‰",
        "СЉ",
        "С‹",
        "СЊ",
        "СҚ",
        "СҺ",
        "СЏ",
    ],
    "mac_cyrillic": [
        "–Р",
        "–С",
        "–Т",
        "–У",
        "–Ф",
        "–Х",
        "–Ц",
        "–Ч",
        "–Ш",
        "–Щ",
        "–Ъ",
        "–Ы",
        "–Ь",
        "–Э",
        "–Ю",
        "–Я",
        "–†",
        "–°",
        "–Ґ",
        "–£",
        "–§",
        "–•",
        "–¶",
        "–І",
        "–®",
        "–©",
        "–™",
        "–Ђ",
        "–ђ",
        "–≠",
        "–Ѓ",
        "–ѓ",
        "вА†",
        "¬∞",
        "“Р",
        "¬£",
        "¬І",
        "вАҐ",
        "¬ґ",
        "–Ж",
        "¬Ѓ",
        "¬©",
        "вДҐ",
        "–В",
        "—Т",
        "вЙ†",
        "–Г",
        "—У",
        "вИЮ",
        "¬±",
        "вЙ§",
        "вЙ•",
        "—Ц",
        "¬µ",
        "“С",
        "–И",
        "–Д",
        "—Ф",
        "–З",
        "—Ч",
        "–Й",
        "—Щ",
        "–К",
        "—Ъ",
        "—Ш",
        "–Е",
        "¬ђ",
        "вИЪ",
        "∆Т",
        "вЙИ",
        "вИЖ",
        "¬Ђ",
        "¬ї",
        "вА¶",
        "¬†",
        "–Л",
        "—Ы",
        "–М",
        "—Ь",
        "—Х",
        "вАУ",
        "вАФ",
        "вАЬ",
        "вАЭ",
        "вАШ",
        "вАЩ",
        "√Ј",
        "вАЮ",
        "–О",
        "—Ю",
        "–П",
        "—Я",
        "вДЦ",
        "–Б",
        "—С",
        "—П",
        "–∞",
        "–±",
        "–≤",
        "–≥",
        "–і",
        "–µ",
        "–ґ",
        "–Ј",
        "–Є",
        "–є",
        "–Ї",
        "–ї",
        "–Љ",
        "–љ",
        "–Њ",
        "–њ",
        "—А",
        "—Б",
        "—В",
        "—Г",
        "—Д",
        "—Е",
        "—Ж",
        "—З",
        "—И",
        "—Й",
        "—К",
        "—Л",
        "—М",
        "—Н",
        "—О",
        "вВђ",
    ],
    "mac_greek": [
        "Ο³",
        "¬Ι",
        "¬≤",
        "Οâ",
        "¬≥",
        "Ο•",
        "Ο€",
        "ΈÖ",
        "Ο†",
        "ΟΔ",
        "ΟΛ",
        "Έ³",
        "¬®",
        "Οß",
        "Ο©",
        "Ο®",
        "ΟΣ",
        "ΟΪ",
        "¬Θ",
        "β³Δ",
        "Ο°",
        "Ο·",
        "βÄΔ",
        "¬Ϋ",
        "βÄΑ",
        "Ο¥",
        "ΟΕ",
        "¬Π",
        "β²§",
        "ΟΙ",
        "ΟΜ",
        "ΟΦ",
        "βÄ†",
        "Έ™",
        "Έî",
        "Έ‰",
        "Έ¦",
        "Έû",
        "Έ†",
        "Οü",
        "¬°",
        "¬©",
        "ΈΘ",
        "ΈΣ",
        "¬ß",
        "βâ†",
        "¬Α",
        "¬Ζ",
        "Έë",
        "¬±",
        "βâΛ",
        "βâΞ",
        "¬Ξ",
        "Έ£",
        "Έï",
        "Έ•",
        "Έ½",
        "Έô",
        "Έö",
        "Έ€",
        "ΈΠ",
        "ΈΪ",
        "Έ®",
        "Έ©",
        "Έ§",
        "Έù",
        "¬§",
        "Έü",
        "ΈΓ",
        "βâà",
        "ΈΛ",
        "¬Ϊ",
        "¬Μ",
        "βÄΠ",
        "¬†",
        "ΈΞ",
        "Έß",
        "ΈÜ",
        "Έà",
        "≈™",
        "βÄ™",
        "βÄï",
        "βÄ€",
        "βÄù",
        "βÄ‰",
        "βÄô",
        "ΟΖ",
        "Έâ",
        "Έä",
        "Έ¨",
        "Έé",
        "Έ≠",
        "Έ°",
        "Έ·",
        "œ¨",
        "Έè",
        "œç",
        "Έ±",
        "Έ≤",
        "œà",
        "Έ¥",
        "ΈΒ",
        "œÜ",
        "Έ≥",
        "ΈΖ",
        "ΈΙ",
        "ΈΨ",
        "ΈΚ",
        "ΈΜ",
        "ΈΦ",
        "ΈΫ",
        "ΈΩ",
        "œÄ",
        "œé",
        "œ¹",
        "œÉ",
        "œ³",
        "ΈΗ",
        "œâ",
        "œ²",
        "œ΅",
        "œÖ",
        "ΈΕ",
        "œä",
        "œ΄",
        "Έê",
        "ΈΑ",
        "¬≠",
    ],
    "mac_iceland": [
        "√Ñ",
        "√Ö",
        "√á",
        "√â",
        "√ë",
        "√ñ",
        "√ú",
        "√°",
        "√Ý",
        "√¢",
        "√§",
        "√£",
        "√•",
        "√ß",
        "√©",
        "√®",
        "√™",
        "√´",
        "√≠",
        "√¨",
        "√Æ",
        "√Ø",
        "√±",
        "√≥",
        "√≤",
        "√¥",
        "√∂",
        "√µ",
        "√∫",
        "√π",
        "√ª",
        "√º",
        "√ù",
        "¬∞",
        "¬¢",
        "¬£",
        "¬ß",
        "‚Ä¢",
        "¬∂",
        "√ü",
        "¬Æ",
        "¬©",
        "‚Ñ¢",
        "¬¥",
        "¬®",
        "‚âÝ",
        "√Ü",
        "√ò",
        "‚àû",
        "¬±",
        "‚â§",
        "‚â•",
        "¬•",
        "¬µ",
        "‚àÇ",
        "‚àë",
        "‚àè",
        "œÄ",
        "‚à´",
        "¬™",
        "¬∫",
        "Œ©",
        "√¶",
        "√∏",
        "¬ø",
        "¬°",
        "¬¨",
        "‚àö",
        "∆í",
        "‚âà",
        "‚àÜ",
        "¬´",
        "¬ª",
        "‚Ä¶",
        "¬Ý",
        "√Ä",
        "√É",
        "√ï",
        "≈í",
        "≈ì",
        "‚Äì",
        "‚Äî",
        "‚Äú",
        "‚Äù",
        "‚Äò",
        "‚Äô",
        "√∑",
        "‚óä",
        "√ø",
        "≈∏",
        "‚ÅÑ",
        "‚Ç¨",
        "√ê",
        "√∞",
        "√û",
        "√æ",
        "√Ω",
        "¬∑",
        "‚Äö",
        "‚Äû",
        "‚Ä∞",
        "√Ç",
        "√ä",
        "√Å",
        "√ã",
        "√à",
        "√ç",
        "√é",
        "√è",
        "√å",
        "√ì",
        "√î",
        "Ô£ø",
        "√í",
        "√ö",
        "√õ",
        "√ô",
        "ƒ±",
        "ÀÜ",
        "Àú",
        "¬Ø",
        "Àò",
        "Àô",
        "Àö",
        "¬∏",
        "Àù",
        "Àõ",
        "Àá",
    ],
    "mac_latin2": [
        "√Ą",
        "ńÄ",
        "ńĀ",
        "√Č",
        "ńĄ",
        "√Ė",
        "√ú",
        "√°",
        "ńÖ",
        "ńĆ",
        "√§",
        "ńć",
        "ńÜ",
        "ńá",
        "√©",
        "ŇĻ",
        "Ňļ",
        "ńé",
        "√≠",
        "ńŹ",
        "ńí",
        "ńď",
        "ńĖ",
        "√≥",
        "ńó",
        "√ī",
        "√∂",
        "√Ķ",
        "√ļ",
        "ńö",
        "ńõ",
        "√ľ",
        "‚Ä†",
        "¬į",
        "ńė",
        "¬£",
        "¬ß",
        "‚ÄĘ",
        "¬∂",
        "√ü",
        "¬ģ",
        "¬©",
        "‚ĄĘ",
        "ńô",
        "¬®",
        "‚Č†",
        "ń£",
        "ńģ",
        "ńĮ",
        "ń™",
        "‚Č§",
        "‚Č•",
        "ńę",
        "ń∂",
        "‚ąā",
        "‚ąĎ",
        "Ňā",
        "ńĽ",
        "ńľ",
        "ńĹ",
        "ńĺ",
        "ńĻ",
        "ńļ",
        "ŇÖ",
        "ŇÜ",
        "ŇÉ",
        "¬¨",
        "‚ąö",
        "ŇĄ",
        "Ňá",
        "‚ąÜ",
        "¬ę",
        "¬Ľ",
        "‚Ä¶",
        "¬†",
        "Ňą",
        "Ňź",
        "√ē",
        "ŇĎ",
        "ŇĆ",
        "‚Äď",
        "‚ÄĒ",
        "‚Äú",
        "‚ÄĚ",
        "‚Äė",
        "‚Äô",
        "√∑",
        "‚óä",
        "Ňć",
        "ŇĒ",
        "Ňē",
        "Ňė",
        "‚ÄĻ",
        "‚Äļ",
        "Ňô",
        "ŇĖ",
        "Ňó",
        "Ň†",
        "‚Äö",
        "‚Äě",
        "Ň°",
        "Ňö",
        "Ňõ",
        "√Ā",
        "Ň§",
        "Ň•",
        "√ć",
        "ŇĹ",
        "Ňĺ",
        "Ň™",
        "√ď",
        "√Ē",
        "Ňę",
        "Ňģ",
        "√ö",
        "ŇĮ",
        "Ňį",
        "ŇĪ",
        "Ň≤",
        "Ň≥",
        "√Ě",
        "√Ĺ",
        "ń∑",
        "ŇĽ",
        "ŇĀ",
        "Ňľ",
        "ńĘ",
        "ňá",
    ],
    "mac_roman": [
        "√Ñ",
        "√Ö",
        "√á",
        "√â",
        "√ë",
        "√ñ",
        "√ú",
        "√°",
        "√†",
        "√¢",
        "√§",
        "√£",
        "√•",
        "√ß",
        "√©",
        "√®",
        "√™",
        "√´",
        "√≠",
        "√¨",
        "√Æ",
        "√Ø",
        "√±",
        "√≥",
        "√≤",
        "√¥",
        "√∂",
        "√µ",
        "√∫",
        "√π",
        "√ª",
        "√º",
        "‚Ä†",
        "¬∞",
        "¬¢",
        "¬£",
        "¬ß",
        "‚Ä¢",
        "¬∂",
        "√ü",
        "¬Æ",
        "¬©",
        "‚Ñ¢",
        "¬¥",
        "¬®",
        "‚â†",
        "√Ü",
        "√ò",
        "‚àû",
        "¬±",
        "‚â§",
        "‚â•",
        "¬•",
        "¬µ",
        "‚àÇ",
        "‚àë",
        "‚àè",
        "œÄ",
        "‚à´",
        "¬™",
        "¬∫",
        "Œ©",
        "√¶",
        "√∏",
        "¬ø",
        "¬°",
        "¬¨",
        "‚àö",
        "∆í",
        "‚âà",
        "‚àÜ",
        "¬´",
        "¬ª",
        "‚Ä¶",
        "¬†",
        "√Ä",
        "√É",
        "√ï",
        "≈í",
        "≈ì",
        "‚Äì",
        "‚Äî",
        "‚Äú",
        "‚Äù",
        "‚Äò",
        "‚Äô",
        "√∑",
        "‚óä",
        "√ø",
        "≈∏",
        "‚ÅÑ",
        "‚Ç¨",
        "‚Äπ",
        "‚Ä∫",
        "Ô¨Å",
        "Ô¨Ç",
        "‚Ä°",
        "¬∑",
        "‚Äö",
        "‚Äû",
        "‚Ä∞",
        "√Ç",
        "√ä",
        "√Å",
        "√ã",
        "√à",
        "√ç",
        "√é",
        "√è",
        "√å",
        "√ì",
        "√î",
        "Ô£ø",
        "√í",
        "√ö",
        "√õ",
        "√ô",
        "ƒ±",
        "ÀÜ",
        "Àú",
        "¬Ø",
        "Àò",
        "Àô",
        "Àö",
        "¬∏",
        "Àù",
        "Àõ",
        "Àá",
    ],
    "mac_turkish": [
        "√Ñ",
        "√Ö",
        "√á",
        "√â",
        "√ë",
        "√ñ",
        "√ú",
        "√°",
        "√†",
        "√¢",
        "√§",
        "√£",
        "√•",
        "√ß",
        "√©",
        "√®",
        "√™",
        "√´",
        "√≠",
        "√¨",
        "√Æ",
        "√Ø",
        "√±",
        "√≥",
        "√≤",
        "√¥",
        "√∂",
        "√µ",
        "√∫",
        "√π",
        "√ª",
        "√º",
        "‚Ä†",
        "¬∞",
        "¬¢",
        "¬£",
        "¬ß",
        "‚Ä¢",
        "¬∂",
        "√ü",
        "¬Æ",
        "¬©",
        "‚Ñ¢",
        "¬¥",
        "¬®",
        "‚â†",
        "√Ü",
        "√ò",
        "‚àû",
        "¬±",
        "‚â§",
        "‚â•",
        "¬•",
        "¬µ",
        "‚àÇ",
        "‚àë",
        "‚àè",
        "œÄ",
        "‚à´",
        "¬™",
        "¬∫",
        "Œ©",
        "√¶",
        "√∏",
        "¬ø",
        "¬°",
        "¬¨",
        "‚àö",
        "∆í",
        "‚âà",
        "‚àÜ",
        "¬´",
        "¬ª",
        "‚Ä¶",
        "¬†",
        "√Ä",
        "√É",
        "√ï",
        "≈í",
        "≈ì",
        "‚Äì",
        "‚Äî",
        "‚Äú",
        "‚Äù",
        "‚Äò",
        "‚Äô",
        "√∑",
        "‚óä",
        "√ø",
        "≈∏",
        "ƒû",
        "ƒü",
        "ƒ∞",
        "ƒ±",
        "≈û",
        "≈ü",
        "‚Ä°",
        "¬∑",
        "‚Äö",
        "‚Äû",
        "‚Ä∞",
        "√Ç",
        "√ä",
        "√Å",
        "√ã",
        "√à",
        "√ç",
        "√é",
        "√è",
        "√å",
        "√ì",
        "√î",
        "Ô£ø",
        "√í",
        "√ö",
        "√õ",
        "√ô",
        "Ô¢†",
        "ÀÜ",
        "Àú",
        "¬Ø",
        "Àò",
        "Àô",
        "Àö",
        "¬∏",
        "Àù",
        "Àõ",
        "Àá",
    ],
    "ptcp154": [
        "Т–",
        "Т’",
        "У®",
        "Т“",
        "вҖһ",
        "вҖҰ",
        "Т¶",
        "Т®",
        "ТІ",
        "ТҜ",
        "Т\xa0",
        "Уў",
        "Тў",
        "Тҡ",
        "Тә",
        "Тё",
        "Т—",
        "вҖҳ",
        "вҖҷ",
        "вҖң",
        "вҖқ",
        "вҖў",
        "вҖ“",
        "вҖ”",
        "Ті",
        "Т·",
        "ТЎ",
        "УЈ",
        "ТЈ",
        "Тӣ",
        "Т»",
        "Т№",
        "В\xa0",
        "РҺ",
        "Сһ",
        "РҲ",
        "УЁ",
        "Тҳ",
        "Т°",
        "В§",
        "РҒ",
        "В©",
        "Уҳ",
        "В«",
        "В¬",
        "УҜ",
        "В®",
        "Тң",
        "В°",
        "Тұ",
        "РҶ",
        "С–",
        "Тҷ",
        "У©",
        "В¶",
        "В·",
        "С‘",
        "в„–",
        "Уҷ",
        "В»",
        "Сҳ",
        "ТӘ",
        "Т«",
        "Тқ",
        "Рҗ",
        "Р‘",
        "Р’",
        "Р“",
        "Р”",
        "Р•",
        "Р–",
        "Р—",
        "Рҳ",
        "Рҷ",
        "Рҡ",
        "Рӣ",
        "Рң",
        "Рқ",
        "Рһ",
        "Рҹ",
        "Р\xa0",
        "РЎ",
        "Рў",
        "РЈ",
        "РӨ",
        "РҘ",
        "РҰ",
        "Р§",
        "РЁ",
        "Р©",
        "РӘ",
        "Р«",
        "Р¬",
        "Рӯ",
        "Р®",
        "РҜ",
        "Р°",
        "Рұ",
        "РІ",
        "Рі",
        "Рҙ",
        "Рө",
        "Р¶",
        "Р·",
        "Рё",
        "Р№",
        "Рә",
        "Р»",
        "Рј",
        "РҪ",
        "Рҫ",
        "Рҝ",
        "СҖ",
        "СҒ",
        "СӮ",
        "Сғ",
        "С„",
        "С…",
        "СҶ",
        "СҮ",
        "СҲ",
        "Сү",
        "СҠ",
        "СӢ",
        "СҢ",
        "СҚ",
        "СҺ",
        "СҸ",
    ],
}


# vim: fileencoding=utf-8 ts=4 sts=4 sw=4 autoindent expandtab syntax=python:
